 
#include <wchar.h>
#include <string.h>

#include "multigraph.h"
/* arch-tag: 130b28cd-e477-458a-bbf7-c5eecef8d763 */


int 
compare_mgraph_exact(const void *a, const void *b) 
{
    const char *aa = a;
    const struct mgraph *bb = b;
    return strcmp(aa, bb->s);
}

int 
compare_mgraph_substr(const void *a, const void *b) 
{
    const char *aa = a;
    const struct mgraph *bb = b;
    return strncmp(aa, bb->s, strlen(aa));
}


struct mgraph mgraphs[] = {
    {    "!!", 0x007c },  /* | VERTICAL LINE */
    {   "!!>", 0x2198 },  /* ↘ SOUTH EAST ARROW */
    {    "!)", 0x007d },  /* } RIGHT CURLY BRACKET */
    {    "!*", 0xe026 },  /*  GREEK VARIA (ISO-10646-1DIS 032/032/042/164) */
    {   "!*2", 0x203c },  /* ‼ DOUBLE EXCLAMATION MARK */
    {    "!2", 0x2016 },  /* ‖ DOUBLE VERTICAL LINE */
    {    "!:", 0x1f06 },  /* ἆ GREEK DIAERESIS AND VARIA */
    {    "!<", 0x226e },  /* ≮ NOT LESS-THAN */
    {    "!=", 0x2260 },  /* ≠ NOT EQUAL TO */
    {    "!>", 0x226f },  /* ≯ NOT GREATER-THAN */
    {    "!I", 0x00a1 },  /* ¡ INVERTED EXCLAMATION MARK */
    {   "\"!", 0xe006 },  /*  NON-SPACING GRAVE ACCENT (ISO-IR-103 193) (character */
    {  "\"\"", 0xe00f },  /*  NON-SPACING DOUBLE ACCUTE (ISO-IR-103 204) (character */
    {   "\"'", 0xe007 },  /*  NON-SPACING ACUTE ACCENT (ISO-IR-103 194) (character */
    {   "\"(", 0xe00b },  /*  NON-SPACING BREVE (ISO-IR-103 198) (character part) */
    {   "\"+", 0x064c },  /* ٌ ARABIC DAMMATAN */
    {   "\",", 0xe011 },  /*  NON-SPACING CEDILLA (ISO-IR-103 203) (character part) */
    {   "\"-", 0xe00a },  /*  NON-SPACING MACRON (ISO-IR-103 197) (character part) */
    {   "\".", 0xe00c },  /*  NON-SPACING DOT ABOVE (ISO-IR-103 199) (character part) */
    {   "\"/", 0xe015 },  /*  NON-SPACING LONG SOLIDUS (ISO-IR-128 201) (character */
    {   "\"0", 0xe00e },  /*  NON-SPACING RING ABOVE (ISO-IR-103 202) (character part) */
    {   "\"1", 0xe005 },  /*  NON-SPACING DIAERESIS WITH ACCENT (ISO-IR-70 192) */
    {   "\"3", 0xe004 },  /*  NON-SPACING UMLAUT (ISO-IR-38 201) (character part) */
    {   "\"5", 0x309b },  /* ゛ KATAKANA-HIRAGANA VOICED SOUND MARK */
    {   "\"6", 0x201c },  /* “ LEFT DOUBLE QUOTATION MARK */
    {   "\"9", 0x201d },  /* ” RIGHT DOUBLE QUOTATION MARK */
    {   "\":", 0xe00d },  /*  NON-SPACING DIAERESIS (ISO-IR-103 200) (character part) */
    {   "\";", 0xe012 },  /*  NON-SPACING OGONEK (ISO-IR-103 206) (character part) */
    {   "\"<", 0xe010 },  /*  NON-SPACING CARON (ISO-IR-103 206) (character part) */
    {   "\"=", 0xe014 },  /*  NON-SPACING DOUBLE LOW LINE (ISO-IR-38 217) (character */
    {   "\">", 0xe008 },  /*  NON-SPACING CIRCUMFLEX ACCENT (ISO-IR-103 195) */
    {   "\"?", 0xe009 },  /*  NON-SPACING TILDE (ISO-IR-103 196) (character part) */
    {   "\"_", 0xe013 },  /*  NON-SPACING LOW LINE (ISO-IR-103 204) (character */
    {   "\"d", 0xe017 },  /*  GREEK NON-SPACING DASIA PNEUMATA (ISO-IR-55 38) */
    {   "\"i", 0xe016 },  /*  GREEK NON-SPACING IOTA BELOW (ISO-IR-55 39) (character */
    {   "\"p", 0xe018 },  /*  GREEK NON-SPACING PSILI PNEUMATA (ISO-IR-55 37) */
    {   "%\"", 0x042c },  /* Ь CYRILLIC CAPITAL LETTER SOFT SIGN */
    {    "%'", 0x044c },  /* ь CYRILLIC SMALL LETTER SOFT SIGN */
    {    "%0", 0x2030 },  /* ‰ PER MILLE SIGN */
    {    "'!", 0x0060 },  /* ` GRAVE ACCENT */
    {   "'\"", 0x02dd },  /* ˝ DOUBLE ACUTE ACCENT */
    {    "'%", 0x03f4 },  /* ϴ ACUTE ACCENT AND DIAERESIS (Tonos and Dialytika) */
    {    "''", 0x00b4 },  /* ´ ACUTE ACCENT */
    {    "'(", 0x02d8 },  /* ˘ BREVE */
    {    "'+", 0x064f },  /* ُ ARABIC DAMMA */
    {    "',", 0x00b8 },  /* ¸ CEDILLA */
    {    "'-", 0x203e },  /* ‾ OVERLINE */
    {    "'.", 0x02d9 },  /* ˙ DOT ABOVE */
    {    "'0", 0x02da },  /* ˚ RING ABOVE */
    {    "'6", 0x2018 },  /* ‘ LEFT SINGLE QUOTATION MARK */
    {    "'9", 0x2019 },  /* ’ RIGHT SINGLE QUOTATION MARK */
    {    "':", 0x00a8 },  /* ¨ DIAERESIS */
    {    "';", 0x02db },  /* ˛ OGONEK */
    {    "'<", 0x02c7 },  /* ˇ CARON */
    {    "'>", 0x005e },  /* ^ CIRCUMFLEX ACCENT */
    {    "'?", 0x007e },  /* ~ TILDE */
    {    "'G", 0x03d8 },  /* Ϙ GREEK NUMERAL SIGN */
    {    "'m", 0x00af },  /* ¯ MACRON */
    {    "'n", 0x0149 },  /* ŉ LATIN SMALL LETTER N PRECEDED BY APOSTROPHE */
    {    "(!", 0x007b },  /* { LEFT CURLY BRACKET */
    {   "(\"", 0x3010 },  /* 【 LEFT BLACK LENTICULAR BRACKET */
    {    "('", 0x3014 },  /* 〔 LEFT TORTOISE SHELL BRACKET */
    {    "(-", 0x2208 },  /* ∈ ELEMENT OF */
    {   "(1)", 0x2474 },  /* ⑴ PARENTHESIZED DIGIT ONE */
    {  "(10)", 0x247d },  /* ⑽ PARENTHESIZED NUMBER TEN */
    {  "(11)", 0x247e },  /* ⑾ PARENTHESIZED NUMBER ELEVEN */
    {  "(12)", 0x247f },  /* ⑿ PARENTHESIZED NUMBER TWELVE */
    {  "(13)", 0x2480 },  /* ⒀ PARENTHESIZED NUMBER THIRTEEN */
    {  "(14)", 0x2481 },  /* ⒁ PARENTHESIZED NUMBER FOURTEEN */
    {  "(15)", 0x2482 },  /* ⒂ PARENTHESIZED NUMBER FIFTEEN */
    {  "(16)", 0x2483 },  /* ⒃ PARENTHESIZED NUMBER SIXTEEN */
    {  "(17)", 0x2484 },  /* ⒄ PARENTHESIZED NUMBER SEVENTEEN */
    {  "(18)", 0x2485 },  /* ⒅ PARENTHESIZED NUMBER EIGHTEEN */
    {  "(19)", 0x2486 },  /* ⒆ PARENTHESIZED NUMBER NINETEEN */
    {   "(2)", 0x2475 },  /* ⑵ PARENTHESIZED DIGIT TWO */
    {  "(20)", 0x2487 },  /* ⒇ PARENTHESIZED NUMBER TWENTY */
    {   "(3)", 0x2476 },  /* ⑶ PARENTHESIZED DIGIT THREE */
    {   "(4)", 0x2477 },  /* ⑷ PARENTHESIZED DIGIT FOUR */
    {   "(5)", 0x2478 },  /* ⑸ PARENTHESIZED DIGIT FIVE */
    {   "(6)", 0x2479 },  /* ⑹ PARENTHESIZED DIGIT SIX */
    {   "(7)", 0x247a },  /* ⑺ PARENTHESIZED DIGIT SEVEN */
    {   "(8)", 0x247b },  /* ⑻ PARENTHESIZED DIGIT EIGHT */
    {   "(9)", 0x247c },  /* ⑼ PARENTHESIZED DIGIT NINE */
    {    "(A", 0x2312 },  /* ⌒ ARC */
    {    "(C", 0x2282 },  /* ⊂ SUBSET OF */
    {    "(I", 0x3016 },  /* 〖 LEFT WHITE LENTICULAR BRACKET */
    {  "(JU)", 0x321c },  /* ㈜ PARENTHESIZED HANGUL JU */
    {    "(S", 0x207d },  /* ⁽ SUPERSCRIPT LEFT PARENTHESIS */
    {    "(U", 0x2229 },  /* ∩ INTERSECTION */
    {    "(_", 0x2286 },  /* ⊆ SUBSET OF OR EQUAL TO */
    {   "(a)", 0x249c },  /* ⒜ PARENTHESIZED LATIN SMALL LETTER A */
    {   "(b)", 0x249d },  /* ⒝ PARENTHESIZED LATIN SMALL LETTER B */
    {   "(c)", 0x249e },  /* ⒞ PARENTHESIZED LATIN SMALL LETTER C */
    {   "(d)", 0x249f },  /* ⒟ PARENTHESIZED LATIN SMALL LETTER D */
    {   "(e)", 0x24a0 },  /* ⒠ PARENTHESIZED LATIN SMALL LETTER E */
    {   "(f)", 0x24a1 },  /* ⒡ PARENTHESIZED LATIN SMALL LETTER F */
    {   "(g)", 0x24a2 },  /* ⒢ PARENTHESIZED LATIN SMALL LETTER G */
    {   "(h)", 0x24a3 },  /* ⒣ PARENTHESIZED LATIN SMALL LETTER H */
    {   "(i)", 0x24a4 },  /* ⒤ PARENTHESIZED LATIN SMALL LETTER I */
    {   "(j)", 0x24a5 },  /* ⒥ PARENTHESIZED LATIN SMALL LETTER J */
    {   "(k)", 0x24a6 },  /* ⒦ PARENTHESIZED LATIN SMALL LETTER K */
    {   "(l)", 0x24a7 },  /* ⒧ PARENTHESIZED LATIN SMALL LETTER L */
    {   "(m)", 0x24a8 },  /* ⒨ PARENTHESIZED LATIN SMALL LETTER M */
    {   "(n)", 0x24a9 },  /* ⒩ PARENTHESIZED LATIN SMALL LETTER N */
    {   "(o)", 0x24aa },  /* ⒪ PARENTHESIZED LATIN SMALL LETTER O */
    {   "(p)", 0x24ab },  /* ⒫ PARENTHESIZED LATIN SMALL LETTER P */
    {   "(q)", 0x24ac },  /* ⒬ PARENTHESIZED LATIN SMALL LETTER Q */
    {   "(r)", 0x24ad },  /* ⒭ PARENTHESIZED LATIN SMALL LETTER R */
    {    "(s", 0x208d },  /* ₍ SUBSCRIPT LEFT PARENTHESIS */
    {   "(s)", 0x24ae },  /* ⒮ PARENTHESIZED LATIN SMALL LETTER S */
    {   "(t)", 0x24af },  /* ⒯ PARENTHESIZED LATIN SMALL LETTER T */
    {   "(u)", 0x24b0 },  /* ⒰ PARENTHESIZED LATIN SMALL LETTER U */
    {   "(v)", 0x24b1 },  /* ⒱ PARENTHESIZED LATIN SMALL LETTER V */
    {   "(w)", 0x24b2 },  /* ⒲ PARENTHESIZED LATIN SMALL LETTER W */
    {   "(x)", 0x24b3 },  /* ⒳ PARENTHESIZED LATIN SMALL LETTER X */
    {   "(y)", 0x24b4 },  /* ⒴ PARENTHESIZED LATIN SMALL LETTER Y */
    {   "(z)", 0x24b5 },  /* ⒵ PARENTHESIZED LATIN SMALL LETTER Z */
    {   ")\"", 0x3011 },  /* 】 RIGHT BLACK LENTICULAR BRACKET */
    {    ")'", 0x3015 },  /* 〕 RIGHT TORTOISE SHELL BRACKET */
    {    ")>", 0x005d },  /* ] RIGHT SQUARE BRACKET */
    {    ")C", 0x2283 },  /* ⊃ SUPERSET OF */
    {    ")I", 0x3017 },  /* 〗 RIGHT WHITE LENTICULAR BRACKET */
    {    ")S", 0x207e },  /* ⁾ SUPERSCRIPT RIGHT PARENTHESIS */
    {    ")U", 0x222a },  /* ∪ UNION */
    {    ")_", 0x2287 },  /* ⊇ SUPERSET OF OR EQUAL TO */
    {    ")s", 0x208e },  /* ₎ SUBSCRIPT RIGHT PARENTHESIS */
    {    "*-", 0x2217 },  /* ∗ ASTERISK OPERATOR */
    {    "*1", 0x2606 },  /* ☆ WHITE STAR */
    {    "*2", 0x2605 },  /* ★ BLACK STAR */
    {    "*5", 0x309d },  /* ゝ HIRAGANA ITERATION MARK */
    {    "*6", 0x30fd },  /* ヽ KATAKANA ITERATION MARK */
    {    "*>", 0x226b },  /* ≫ MUCH GREATER-THAN */
    {    "*P", 0x220f },  /* ∏ N-ARY PRODUCT */
    {    "*X", 0x00d7 },  /* × MULTIPLICATION SIGN */
    {    "*_", 0x3005 },  /* 々 IDEOGRAPHIC ITERATION MARK */
    {    "*s", 0x03c2 },  /* ς GREEK SMALL LETTER FINAL SIGMA */
    {   "+\"", 0x3003 },  /* 〃 DITTO MARK */
    {    "++", 0x0640 },  /* ـ ARABIC TATWEEL */
    {    "+-", 0x00b1 },  /* ± PLUS-MINUS SIGN */
    {    "+5", 0x309e },  /* ゞ HIRAGANA VOICED ITERATION MARK */
    {    "+6", 0x30fe },  /* ヾ KATAKANA VOICED ITERATION MARK */
    {    "+S", 0x207a },  /* ⁺ SUPERSCRIPT PLUS SIGN */
    {    "+Z", 0x2211 },  /* ∑ N-ARY SUMMATION */
    {    "+_", 0x3004 },  /* 〄 IDEOGRAPHIC DITTO MARK */
    {    "+s", 0x208a },  /* ₊ SUBSCRIPT PLUS SIGN */
    {    ",!", 0x1f03 },  /* ἃ GREEK PSILI AND VARIA */
    {    ",'", 0x1f01 },  /* ἁ GREEK PSILI AND ACUTE ACCENT */
    {    ",+", 0x060c },  /* ، ARABIC COMMA */
    {    ",,", 0xe01a },  /*  GREEK PSILI PNEUMATA (ISO-IR-18 124) */
    {    ",G", 0x03d9 },  /* ϙ GREEK LOWER NUMERAL SIGN */
    {    ",_", 0x3001 },  /* 、 IDEOGRAPHIC COMMA */
    {    "-!", 0x2191 },  /* ↑ UPWARDS ARROW */
    {    "-)", 0x220b },  /* ∋ CONTAINS AS MEMBER */
    {    "-+", 0x2213 },  /* ∓ MINUS-OR-PLUS SIGN */
    {    "--", 0x00ad },  /* ­ SOFT HYPHEN */
    {    "-1", 0x2010 },  /* ‐ HYPHEN */
    {    "-2", 0x2212 },  /* − MINUS SIGN */
    {    "-3", 0x2015 },  /* ― HORIZONTAL BAR */
    {    "-6", 0x30fc },  /* ー KATAKANA-HIRAGANA PROLONGED SOUND MARK */
    {    "-:", 0x00f7 },  /* ÷ DIVISION SIGN */
    {    "->", 0x2192 },  /* → RIGHTWARDS ARROW */
    {    "-?", 0x301c },  /* 〜 WAVE DASH */
    {    "-L", 0x221f },  /* ∟ RIGHT ANGLE */
    {    "-M", 0x2014 },  /* — EM DASH */
    {    "-N", 0x2013 },  /* – EN DASH */
    {    "-S", 0x207b },  /* ⁻ SUPERSCRIPT MINUS */
    {    "-T", 0x22a5 },  /* ⊥ UP TACK */
    {    "-V", 0x2220 },  /* ∠ ANGLE */
    {    "-X", 0x2720 },  /* ✠ MALTESE CROSS */
    {    "-a", 0x00aa },  /* ª FEMININE ORDINAL INDICATOR */
    {    "-o", 0x00ba },  /* º MASCULINE ORDINAL INDICATOR */
    {    "-s", 0x208b },  /* ₋ SUBSCRIPT MINUS */
    {    "-v", 0x2193 },  /* ↓ DOWNWARDS ARROW */
    {    "..", 0x2025 },  /* ‥ TWO DOT LEADER */
    {    ".3", 0x22ef },  /* ⋯ MIDLINE HORIZONTAL ELLIPSIS */
    {    ".6", 0x30fb },  /* ・ KATAKANA MIDDLE DOT */
    {    ".9", 0x201a },  /* ‚ SINGLE LOW-9 QUOTATION MARK */
    {    ".:", 0x2234 },  /* ∴ THEREFORE */
    {    ".M", 0x00b7 },  /* · MIDDLE DOT */
    {    ".P", 0x22c5 },  /* ⋅ DOT OPERATOR */
    {    ".S", 0x2591 },  /* ░ LIGHT SHADE */
    {    "._", 0x3002 },  /* 。 IDEOGRAPHIC PERIOD */
    {    "/+", 0x064e },  /* َ ARABIC FATHA */
    {    "/-", 0x2020 },  /* † DAGGER */
    {    "//", 0x005c },  /* \ REVERSE SOLIDUS */
    {   "//>", 0x2197 },  /* ↗ NORTH EAST ARROW */
    {    "/0", 0x2205 },  /* ∅ EMPTY SET */
    {    "/=", 0x2021 },  /* ‡ DOUBLE DAGGER */
    {    "/>", 0x232a },  /* 〉 RIGHT-POINTING ANGLE BRACKET */
    {    "/c", 0xe001 },  /*  JOIN THIS LINE WITH NEXT LINE (Mnemonic) */
    {    "/f", 0x2044 },  /* ⁄ FRACTION SLASH */
    {    "0(", 0x221d },  /* ∝ PROPORTIONAL TO */
    {    "0+", 0x0652 },  /* ْ ARABIC SUKUN */
    {   "0-o", 0x24ea },  /* ⓪ CIRCLED DIGIT ZERO */
    {    "0.", 0x2299 },  /* ⊙ CIRCLED DOT OPERATOR */
    {    "00", 0x221e },  /* ∞ INFINITY */
    {    "02", 0x229a },  /* ⊚ CIRCLED RING OPERATOR */
    {    "05", 0x309c },  /* ゜ KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK */
    {    "0L", 0x25d0 },  /* ◐ CIRCLE WITH LEFT HALF BLACK */
    {    "0M", 0x25cf },  /* ● BLACK CIRCLE */
    {    "0R", 0x25d1 },  /* ◑ CIRCLE WITH RIGHT HALF BLACK */
    {    "0S", 0x2070 },  /* ⁰ SUPERSCRIPT DIGIT ZERO */
    {    "0U", 0x263b },  /* ☻ BLACK SMILING FACE */
    {    "0_", 0x3007 },  /* 〇 IDEOGRAPHIC NUMBER ZERO */
    {    "0a", 0x06f0 },  /* ۰ EASTERN ARABIC-INDIC DIGIT ZERO */
    {    "0m", 0x25cb },  /* ○ WHITE CIRCLE */
    {    "0o", 0x25ce },  /* ◎ BULLSEYE */
    {    "0s", 0x2080 },  /* ₀ SUBSCRIPT DIGIT ZERO */
    {    "0u", 0x263a },  /* ☺ WHITE SMILING FACE */
    {   "1\"", 0x2035 },  /* ‵ REVERSED PRIME */
    {    "1'", 0x2032 },  /* ′ PRIME */
    {    "1+", 0x0650 },  /* ِ ARABIC KASRA */
    {   "1-o", 0x2460 },  /* ① CIRCLED DIGIT ONE */
    {    "1.", 0x2488 },  /* ⒈ DIGIT ONE FULL STOP */
    {  "10-o", 0x2469 },  /* ⑩ CIRCLED NUMBER TEN */
    {   "10.", 0x2491 },  /* ⒑ NUMBER TEN FULL STOP */
    { "10000R", 0x2182 },  /* ↂ ROMAN NUMERAL TEN THOUSAND */
    { "1000R", 0x216f },  /* Ⅿ ROMAN NUMERAL ONE THOUSAND */
    { "1000RCD", 0x2180 },  /* ↀ ROMAN NUMERAL ONE THOUSAND C D */
    { "1000r", 0x217f },  /* ⅿ SMALL ROMAN NUMERAL ONE THOUSAND */
    {  "100R", 0x216d },  /* Ⅽ ROMAN NUMERAL ONE HUNDRED */
    {  "100r", 0x217d },  /* ⅽ SMALL ROMAN NUMERAL ONE HUNDRED */
    {   "10c", 0x3229 },  /* ㈩ PARENTHESIZED IDEOGRAPH TEN */
    {  "11-o", 0x246a },  /* ⑪ CIRCLED NUMBER ELEVEN */
    {   "11.", 0x2492 },  /* ⒒ NUMBER ELEVEN FULL STOP */
    {    "12", 0x00bd },  /* ½ VULGAR FRACTION ONE HALF */
    {  "12-o", 0x246b },  /* ⑫ CIRCLED NUMBER TWELVE */
    {   "12.", 0x2493 },  /* ⒓ NUMBER TWELVE FULL STOP */
    {    "13", 0x2153 },  /* ⅓ VULGAR FRACTION ONE THIRD */
    {  "13-o", 0x246c },  /* ⑬ CIRCLED NUMBER THIRTEEN */
    {   "13.", 0x2494 },  /* ⒔ NUMBER THIRTEEN FULL STOP */
    {    "14", 0x00bc },  /* ¼ VULGAR FRACTION ONE QUARTER */
    {  "14-o", 0x246d },  /* ⑭ CIRCLED NUMBER FOURTEEN */
    {   "14.", 0x2495 },  /* ⒕ NUMBER FOURTEEN FULL STOP */
    {    "15", 0x2155 },  /* ⅕ VULGAR FRACTION ONE FIFTH */
    {  "15-o", 0x246e },  /* ⑮ CIRCLED NUMBER FIFTEEN */
    {   "15.", 0x2496 },  /* ⒖ NUMBER FIFTEEN FULL STOP */
    {    "16", 0x2159 },  /* ⅙ VULGAR FRACTION ONE SIXTH */
    {  "16-o", 0x246f },  /* ⑯ CIRCLED NUMBER SIXTEEN */
    {   "16.", 0x2497 },  /* ⒗ NUMBER SIXTEEN FULL STOP */
    {  "17-o", 0x2470 },  /* ⑰ CIRCLED NUMBER SEVENTEEN */
    {   "17.", 0x2498 },  /* ⒘ NUMBER SEVENTEEN FULL STOP */
    {    "18", 0x215b },  /* ⅛ VULGAR FRACTION ONE EIGHTH */
    {  "18-o", 0x2471 },  /* ⑱ CIRCLED NUMBER EIGHTEEN */
    {   "18.", 0x2499 },  /* ⒙ NUMBER EIGHTEEN FULL STOP */
    {  "19-o", 0x2472 },  /* ⑲ CIRCLED NUMBER NINETEEN */
    {   "19.", 0x249a },  /* ⒚ NUMBER NINETEEN FULL STOP */
    {    "1H", 0x200a },  /*   HAIR SPACE */
    {    "1M", 0x2003 },  /*   EM SPACE */
    {    "1N", 0x2002 },  /*   EN SPACE */
    {    "1R", 0x2160 },  /* Ⅰ ROMAN NUMERAL ONE */
    {    "1S", 0x00b9 },  /* ¹ SUPERSCRIPT ONE */
    {    "1T", 0x2009 },  /*   THIN SPACE */
    {    "1a", 0x06f1 },  /* ۱ EASTERN ARABIC-INDIC DIGIT ONE */
    {    "1c", 0x3220 },  /* ㈠ PARENTHESIZED IDEOGRAPH ONE */
    {    "1h", 0x2440 },  /* ⑀ OCR HOOK */
    {    "1j", 0x2446 },  /* ⑆ OCR BRANCH BANK IDENTIFICATION */
    {    "1r", 0x2170 },  /* ⅰ SMALL ROMAN NUMERAL ONE */
    {    "1s", 0x2081 },  /* ₁ SUBSCRIPT DIGIT ONE */
    {   "2\"", 0x2036 },  /* ‶ REVERSED DOUBLE PRIME */
    {    "2'", 0x2033 },  /* ″ DOUBLE PRIME */
    {   "2-o", 0x2461 },  /* ② CIRCLED DIGIT TWO */
    {    "2.", 0x2489 },  /* ⒉ DIGIT TWO FULL STOP */
    {  "20-o", 0x2473 },  /* ⑳ CIRCLED NUMBER TWENTY */
    {   "20.", 0x249b },  /* ⒛ NUMBER TWENTY FULL STOP */
    {    "23", 0x2154 },  /* ⅔ VULGAR FRACTION TWO THIRDS */
    {    "25", 0x2156 },  /* ⅖ VULGAR FRACTION TWO FIFTHS */
    {    "2R", 0x2161 },  /* Ⅱ ROMAN NUMERAL TWO */
    {    "2S", 0x00b2 },  /* ² SUPERSCRIPT TWO */
    {    "2a", 0x06f2 },  /* ۲ EASTERN ARABIC-INDIC DIGIT TWO */
    {    "2c", 0x3221 },  /* ㈡ PARENTHESIZED IDEOGRAPH TWO */
    {    "2h", 0x2442 },  /* ⑂ OCR FORK */
    {    "2j", 0x2447 },  /* ⑇ OCR AMOUNT OF CHECK */
    {    "2r", 0x2171 },  /* ⅱ SMALL ROMAN NUMERAL TWO */
    {    "2s", 0x2082 },  /* ₂ SUBSCRIPT DIGIT TWO */
    {    "3!", 0x2506 },  /* ┆ BOX DRAWINGS LIGHT TRIPLE DASH VERTICAL */
    {   "3\"", 0x2037 },  /* ‷ REVERSED TRIPLE PRIME */
    {    "3'", 0x2034 },  /* ‴ TRIPLE PRIME */
    {    "3+", 0x0651 },  /* ّ ARABIC SHADDA */
    {   "3+;", 0xfe7d },  /* ﹽ ARABIC SHADDA MEDIAL FORM */
    {    "3-", 0x2504 },  /* ┄ BOX DRAWINGS LIGHT TRIPLE DASH HORIZONTAL */
    {   "3-o", 0x2462 },  /* ③ CIRCLED DIGIT THREE */
    {    "3.", 0x248a },  /* ⒊ DIGIT THREE FULL STOP */
    {    "3/", 0x2507 },  /* ┇ BOX DRAWINGS HEAVY TRIPLE DASH VERTICAL */
    {    "34", 0x00be },  /* ¾ VULGAR FRACTION THREE QUARTERS */
    {    "35", 0x2157 },  /* ⅗ VULGAR FRACTION THREE FIFTHS */
    {    "38", 0x215c },  /* ⅜ VULGAR FRACTION THREE EIGHTHS */
    {    "3M", 0x2004 },  /*   THREE-PER-EM SPACE */
    {    "3R", 0x2162 },  /* Ⅲ ROMAN NUMERAL THREE */
    {    "3S", 0x00b3 },  /* ³ SUPERSCRIPT THREE */
    {    "3_", 0x2505 },  /* ┅ BOX DRAWINGS HEAVY TRIPLE DASH HORIZONTAL */
    {    "3a", 0x06f3 },  /* ۳ EASTERN ARABIC-INDIC DIGIT THREE */
    {    "3c", 0x3222 },  /* ㈢ PARENTHESIZED IDEOGRAPH THREE */
    {    "3h", 0x2441 },  /* ⑁ OCR CHAIR */
    {    "3j", 0x2448 },  /* ⑈ OCR DASH */
    {    "3r", 0x2172 },  /* ⅲ SMALL ROMAN NUMERAL THREE */
    {    "3s", 0x2083 },  /* ₃ SUBSCRIPT DIGIT THREE */
    {    "4!", 0x250a },  /* ┊ BOX DRAWINGS LIGHT QUADRUPLE DASH VERTICAL */
    {    "4-", 0x2508 },  /* ┈ BOX DRAWINGS LIGHT QUADRUPLE DASH HORIZONTAL */
    {   "4-o", 0x2463 },  /* ④ CIRCLED DIGIT FOUR */
    {    "4.", 0x248b },  /* ⒋ DIGIT FOUR FULL STOP */
    {    "4/", 0x250b },  /* ┋ BOX DRAWINGS HEAVY QUADRUPLE DASH VERTICAL */
    {    "45", 0x2158 },  /* ⅘ VULGAR FRACTION FOUR FIFTHS */
    {    "4M", 0x2005 },  /*   FOUR-PER-EM SPACE */
    {    "4R", 0x2163 },  /* Ⅳ ROMAN NUMERAL FOUR */
    {    "4S", 0x2074 },  /* ⁴ SUPERSCRIPT DIGIT FOUR */
    {    "4_", 0x2509 },  /* ┉ BOX DRAWINGS HEAVY QUADRUPLE DASH HORIZONTAL */
    {    "4a", 0x06f4 },  /* ۴ EASTERN ARABIC-INDIC DIGIT FOUR */
    {    "4c", 0x3223 },  /* ㈣ PARENTHESIZED IDEOGRAPH FOUR */
    {    "4h", 0x2443 },  /* ⑃ OCR INVERTED FORK */
    {    "4j", 0x2449 },  /* ⑉ OCR CUSTOMER ACCOUNT NUMBER */
    {    "4r", 0x2173 },  /* ⅳ SMALL ROMAN NUMERAL FOUR */
    {    "4s", 0x2084 },  /* ₄ SUBSCRIPT DIGIT FOUR */
    {   "5-o", 0x2464 },  /* ⑤ CIRCLED DIGIT FIVE */
    {    "5.", 0x248c },  /* ⒌ DIGIT FIVE FULL STOP */
    { "5000R", 0x2181 },  /* ↁ ROMAN NUMERAL FIVE THOUSAND */
    {  "500R", 0x216e },  /* Ⅾ ROMAN NUMERAL FIVE HUNDRED */
    {  "500r", 0x217e },  /* ⅾ SMALL ROMAN NUMERAL FIVE HUNDRED */
    {   "50R", 0x216c },  /* Ⅼ ROMAN NUMERAL FIFTY */
    {   "50r", 0x217c },  /* ⅼ SMALL ROMAN NUMERAL FIFTY */
    {    "56", 0x215a },  /* ⅚ VULGAR FRACTION FIVE SIXTHS */
    {    "58", 0x215d },  /* ⅝ VULGAR FRACTION FIVE EIGHTHS */
    {    "5R", 0x2164 },  /* Ⅴ ROMAN NUMERAL FIVE */
    {    "5S", 0x2075 },  /* ⁵ SUPERSCRIPT DIGIT FIVE */
    {    "5a", 0x06f5 },  /* ۵ EASTERN ARABIC-INDIC DIGIT FIVE */
    {    "5c", 0x3224 },  /* ㈤ PARENTHESIZED IDEOGRAPH FIVE */
    {    "5r", 0x2174 },  /* ⅴ SMALL ROMAN NUMERAL FIVE */
    {    "5s", 0x2085 },  /* ₅ SUBSCRIPT DIGIT FIVE */
    {   "6-o", 0x2465 },  /* ⑥ CIRCLED DIGIT SIX */
    {    "6.", 0x248d },  /* ⒍ DIGIT SIX FULL STOP */
    {    "6M", 0x2006 },  /*   SIX-PER-EM SPACE */
    {    "6R", 0x2165 },  /* Ⅵ ROMAN NUMERAL SIX */
    {    "6S", 0x2076 },  /* ⁶ SUPERSCRIPT DIGIT SIX */
    {    "6a", 0x06f6 },  /* ۶ EASTERN ARABIC-INDIC DIGIT SIX */
    {    "6c", 0x3225 },  /* ㈥ PARENTHESIZED IDEOGRAPH SIX */
    {    "6r", 0x2175 },  /* ⅵ SMALL ROMAN NUMERAL SIX */
    {    "6s", 0x2086 },  /* ₆ SUBSCRIPT DIGIT SIX */
    {   "7-o", 0x2466 },  /* ⑦ CIRCLED DIGIT SEVEN */
    {    "7.", 0x248e },  /* ⒎ DIGIT SEVEN FULL STOP */
    {    "78", 0x215e },  /* ⅞ VULGAR FRACTION SEVEN EIGHTHS */
    {    "7<", 0x230a },  /* ⌊ LEFT FLOOR */
    {    "7>", 0x230b },  /* ⌋ RIGHT FLOOR */
    {    "7R", 0x2166 },  /* Ⅶ ROMAN NUMERAL SEVEN */
    {    "7S", 0x2077 },  /* ⁷ SUPERSCRIPT DIGIT SEVEN */
    {    "7a", 0x06f7 },  /* ۷ EASTERN ARABIC-INDIC DIGIT SEVEN */
    {    "7c", 0x3226 },  /* ㈦ PARENTHESIZED IDEOGRAPH SEVEN */
    {    "7r", 0x2176 },  /* ⅶ SMALL ROMAN NUMERAL SEVEN */
    {    "7s", 0x2087 },  /* ₇ SUBSCRIPT DIGIT SEVEN */
    {   "8-o", 0x2467 },  /* ⑧ CIRCLED DIGIT EIGHT */
    {    "8.", 0x248f },  /* ⒏ DIGIT EIGHT FULL STOP */
    {    "8R", 0x2167 },  /* Ⅷ ROMAN NUMERAL EIGHT */
    {    "8S", 0x2078 },  /* ⁸ SUPERSCRIPT DIGIT EIGHT */
    {    "8a", 0x06f8 },  /* ۸ EASTERN ARABIC-INDIC DIGIT EIGHT */
    {    "8c", 0x3227 },  /* ㈧ PARENTHESIZED IDEOGRAPH EIGHT */
    {    "8r", 0x2177 },  /* ⅷ SMALL ROMAN NUMERAL EIGHT */
    {    "8s", 0x2088 },  /* ₈ SUBSCRIPT DIGIT EIGHT */
    {   "9\"", 0x201f },  /* ‟ DOUBLE HIGH-REVERSED-9 QUOTATION MARK */
    {    "9'", 0x201b },  /* ‛ SINGLE HIGH-REVERSED-9 QUOTATION MARK */
    {   "9-o", 0x2468 },  /* ⑨ CIRCLED DIGIT NINE */
    {    "9.", 0x2490 },  /* ⒐ DIGIT NINE FULL STOP */
    {    "9R", 0x2168 },  /* Ⅸ ROMAN NUMERAL NINE */
    {    "9S", 0x2079 },  /* ⁹ SUPERSCRIPT DIGIT NINE */
    {    "9a", 0x06f9 },  /* ۹ EASTERN ARABIC-INDIC DIGIT NINE */
    {    "9c", 0x3228 },  /* ㈨ PARENTHESIZED IDEOGRAPH NINE */
    {    "9r", 0x2178 },  /* ⅸ SMALL ROMAN NUMERAL NINE */
    {    "9s", 0x2089 },  /* ₉ SUBSCRIPT DIGIT NINE */
    {    ":+", 0x064b },  /* ً ARABIC FATHATAN */
    {    ":.", 0x2235 },  /* ∵ BECAUSE */
    {    ":3", 0x22ee },  /* ⋮ VERTICAL ELLIPSIS */
    {    ":9", 0x201e },  /* „ DOUBLE LOW-9 QUOTATION MARK */
    {    "::", 0x2237 },  /* ∷ PROPORTION */
    {    ":R", 0x2236 },  /* ∶ RATIO */
    {    ":S", 0x2592 },  /* ▒ MEDIUM SHADE */
    {    ":X", 0x203b },  /* ※ REFERENCE MARK */
    {    ";!", 0x1f02 },  /* ἂ GREEK DASIA AND VARIA */
    {    ";'", 0x1f00 },  /* ἀ GREEK DASIA AND ACUTE ACCENT */
    {    ";+", 0x061b },  /* ؛ ARABIC SEMICOLON */
    {    ";;", 0xe019 },  /*  GREEK DASIA PNEUMATA (ISO-IR-18 92) */
    {    ";S", 0x02bf },  /* ʿ MODIFIER LETTER LEFT HALF RING */
    {    ";_", 0x3006 },  /* 〆 IDEOGRAPHIC CLOSING MARK */
    {   "<!!", 0x2196 },  /* ↖ NORTH WEST ARROW */
    {   "<\"", 0x300e },  /* 『 LEFT WHITE CORNER BRACKET */
    {    "<'", 0x300c },  /* 「 LEFT CORNER BRACKET */
    {    "<(", 0x005b },  /* [ LEFT SQUARE BRACKET */
    {    "<*", 0x226a },  /* ≪ MUCH LESS-THAN */
    {    "<+", 0x300a },  /* 《 LEFT DOUBLE ANGLE BRACKET */
    {    "<-", 0x2190 },  /* ← LEFTWARDS ARROW */
    {    "</", 0x2329 },  /* 〈 LEFT-POINTING ANGLE BRACKET */
    {   "<//", 0x2199 },  /* ↙ SOUTH WEST ARROW */
    {    "<1", 0x2039 },  /* ‹ SINGLE LEFT-POINTING ANGLE QUOTATION MARK */
    {    "<7", 0x2308 },  /* ⌈ LEFT CEILING */
    {    "<<", 0x00ab },  /* « LEFT-POINTING DOUBLE ANGLE QUOTATION MARK */
    {    "<=", 0x21d0 },  /* ⇐ LEFTWARDS DOUBLE ARROW */
    {    "<>", 0x2194 },  /* ↔ LEFT RIGHT ARROW */
    {    "<H", 0x261c },  /* ☜ WHITE LEFT POINTING INDEX */
    {   "=\"", 0x042a },  /* Ъ CYRILLIC CAPITAL LETTER HARD SIGN */
    {    "='", 0x044a },  /* ъ CYRILLIC SMALL LETTER HARD SIGN */
    {    "=+", 0x064d },  /* ٍ ARABIC KASRATAN */
    {    "=2", 0x2017 },  /* ‗ DOUBLE LOW LINE */
    {    "=3", 0x2261 },  /* ≡ IDENTICAL TO */
    {    "=<", 0x2264 },  /* ≤ LESS-THAN OR EQUAL TO */
    {    "==", 0x21d4 },  /* ⇔ LEFT RIGHT DOUBLE ARROW */
    {    "=>", 0x21d2 },  /* ⇒ RIGHTWARDS DOUBLE ARROW */
    {    "=?", 0x224c },  /* ≌ ALL EQUAL TO */
    {    "=S", 0x207c },  /* ⁼ SUPERSCRIPT EQUALS SIGN */
    {    "=T", 0x3012 },  /* 〒 POSTAL MARK */
    {  "=T:)", 0x3020 },  /* 〠 POSTAL MARK FACE */
    {    "=_", 0x3013 },  /* 〓 GETA MARK */
    {    "=s", 0x208c },  /* ₌ SUBSCRIPT EQUALS SIGN */
    {   ">\"", 0x300f },  /* 』 RIGHT WHITE CORNER BRACKET */
    {    ">'", 0x300d },  /* 」 RIGHT CORNER BRACKET */
    {    ">+", 0x300b },  /* 》 RIGHT DOUBLE ANGLE BRACKET */
    {    ">1", 0x203a },  /* › SINGLE RIGHT-POINTING ANGLE QUOTATION MARK */
    {    ">7", 0x2309 },  /* ⌉ RIGHT CEILING */
    {    ">=", 0x2265 },  /* ≥ GREATER-THAN OR EQUAL TO */
    {    ">>", 0x00bb },  /* » RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK */
    {    ">H", 0x261e },  /* ☞ WHITE RIGHT POINTING INDEX */
    {    ">V", 0xe025 },  /*  RIGHTWARDS VECTOR ABOVE (ISO-10646-1DIS 032/032/038/046) */
    {    "?*", 0xe027 },  /*  GREEK PERISPOMENI (ISO-10646-1DIS 032/032/042/165) */
    {    "?+", 0x061f },  /* ؟ ARABIC QUESTION MARK */
    {    "?,", 0x1f05 },  /* ἅ GREEK PSILI AND PERISPOMENI */
    {    "?-", 0x2243 },  /* ≃ ASYMPTOTICALLY EQUAL TO */
    {    "?1", 0x223c },  /* ∼ TILDE OPERATOR */
    {    "?2", 0x2248 },  /* ≈ ALMOST EQUAL TO */
    {    "?:", 0x1f07 },  /* ἇ GREEK DIAERESIS AND PERISPOMENI */
    {    "?;", 0x1f04 },  /* ἄ GREEK DASIA AND PERISPOMENI */
    {    "?=", 0x2245 },  /* ≅ APPROXIMATELY EQUAL TO */
    {    "?I", 0x00bf },  /* ¿ INVERTED QUESTION MARK */
    {    "?S", 0x2593 },  /* ▓ DARK SHADE */
    {    "A!", 0x00c0 },  /* À LATIN CAPITAL LETTER A WITH GRAVE */
    {    "A%", 0x0386 },  /* Ά GREEK CAPITAL LETTER ALPHA WITH ACUTE */
    {    "A'", 0x00c1 },  /* Á LATIN CAPITAL LETTER A WITH ACUTE */
    {    "A(", 0x0102 },  /* Ă LATIN CAPITAL LETTER A WITH BREVE */
    {   "A(!", 0x1eb0 },  /* Ằ LATIN CAPITAL LETTER A WITH BREVE AND GRAVE */
    {   "A('", 0x1eae },  /* Ắ LATIN CAPITAL LETTER A WITH BREVE AND ACUTE */
    {  "A(-.", 0x1eb6 },  /* Ặ LATIN CAPITAL LETTER A WITH BREVE AND DOT BELOW */
    {   "A(2", 0x1eb2 },  /* Ẳ LATIN CAPITAL LETTER A WITH BREVE AND HOOK ABOVE */
    {   "A(?", 0x1eb4 },  /* Ẵ LATIN CAPITAL LETTER A WITH BREVE AND TILDE */
    {    "A*", 0x0391 },  /* Α GREEK CAPITAL LETTER ALPHA */
    {    "A+", 0x05d0 },  /* א HEBREW LETTER ALEF */
    {    "A-", 0x0100 },  /* Ā LATIN CAPITAL LETTER A WITH MACRON */
    {   "A-.", 0x1ea0 },  /* Ạ LATIN CAPITAL LETTER A WITH DOT BELOW */
    {   "A-0", 0x1e00 },  /* Ḁ LATIN CAPITAL LETTER A WITH RING BELOW */
    {   "A-o", 0x24b6 },  /* Ⓐ CIRCLED LATIN CAPITAL LETTER A */
    {    "A1", 0x01de },  /* Ǟ LATIN CAPITAL LETTER A WITH DIAERESIS AND MACRON */
    {    "A2", 0x1ea2 },  /* Ả LATIN CAPITAL LETTER A WITH HOOK ABOVE */
    {    "A3", 0x01e2 },  /* Ǣ LATIN CAPITAL LETTER AE WITH MACRON */
    {    "A5", 0x3041 },  /* ぁ HIRAGANA LETTER SMALL A */
    {    "A6", 0x30a2 },  /* ア KATAKANA LETTER A */
    {    "A7", 0x01e0 },  /* Ǡ LATIN CAPITAL LETTER A WITH DOT ABOVE AND MACRON */
    {    "A:", 0x00c4 },  /* Ä LATIN CAPITAL LETTER A WITH DIAERESIS */
    {    "A;", 0x0104 },  /* Ą LATIN CAPITAL LETTER A WITH OGONEK */
    {    "A<", 0x01cd },  /* Ǎ LATIN CAPITAL LETTER A WITH CARON */
    {    "A=", 0x0410 },  /* А CYRILLIC CAPITAL LETTER A */
    {    "A>", 0x00c2 },  /* Â LATIN CAPITAL LETTER A WITH CIRCUMFLEX */
    {   "A>!", 0x1ea6 },  /* Ầ LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND GRAVE */
    {   "A>'", 0x1ea4 },  /* Ấ LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND ACUTE */
    {  "A>-.", 0x1eac },  /* Ậ LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND DOT BELOW */
    {   "A>2", 0x1ea8 },  /* Ẩ LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE */
    {   "A>?", 0x1eaa },  /* Ẫ LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND TILDE */
    {    "A?", 0x00c3 },  /* Ã LATIN CAPITAL LETTER A WITH TILDE */
    {    "AA", 0x00c5 },  /* Å LATIN CAPITAL LETTER A WITH RING ABOVE */
    {   "AA'", 0x01fa },  /* Ǻ LATIN CAPITAL LETTER A WITH RING ABOVE AND ACUTE */
    {    "AC", 0x009f },  /*   APPLICATION PROGRAM COMMAND (APC) */
    {    "AE", 0x00c6 },  /* Æ LATIN CAPITAL LETTER AE */
    {   "AE'", 0x01fc },  /* Ǽ LATIN CAPITAL LETTER AE WITH ACUTE */
    {    "AK", 0x0006 },  /*   ACKNOWLEDGE (ACK) */
    {    "AN", 0x2227 },  /* ∧ LOGICAL AND */
    {    "AO", 0x212b },  /* Å ANGSTROEM SIGN */
    {    "At", 0x0040 },  /* @ COMMERCIAL AT */
    {    "B*", 0x0392 },  /* Β GREEK CAPITAL LETTER BETA */
    {    "B+", 0x05d1 },  /* ב HEBREW LETTER BET */
    {   "B-.", 0x1e04 },  /* Ḅ LATIN CAPITAL LETTER B WITH DOT BELOW */
    {   "B-o", 0x24b7 },  /* Ⓑ CIRCLED LATIN CAPITAL LETTER B */
    {    "B.", 0x1e02 },  /* Ḃ LATIN CAPITAL LETTER B WITH DOT ABOVE */
    {    "B=", 0x0411 },  /* Б CYRILLIC CAPITAL LETTER BE */
    {    "BB", 0x00a6 },  /* ¦ BROKEN BAR */
    {    "BD", 0x2572 },  /* ╲ BOX DRAWINGS LIGHT DIAGONAL UPPER LEFT TO LOWER RIGHT */
    {    "BH", 0x0082 },  /*   BREAK PERMITTED HERE (BPH) */
    {    "BL", 0x0007 },  /*   BELL (BEL) */
    {    "BS", 0x0008 },  /*   BACKSPACE (BS) */
    {    "B_", 0x1e06 },  /* Ḇ LATIN CAPITAL LETTER B WITH LINE BELOW */
    {    "Ba", 0x30d0 },  /* バ KATAKANA LETTER BA */
    {    "Bd", 0x25e3 },  /* ◣ BLACK LOWER LEFT TRIANGLE */
    {    "Be", 0x30d9 },  /* ベ KATAKANA LETTER BE */
    {    "Bi", 0x30d3 },  /* ビ KATAKANA LETTER BI */
    {    "Bo", 0x30dc },  /* ボ KATAKANA LETTER BO */
    {    "Bu", 0x30d6 },  /* ブ KATAKANA LETTER BU */
    {    "C%", 0x0427 },  /* Ч CYRILLIC CAPITAL LETTER CHE */
    {    "C'", 0x0106 },  /* Ć LATIN CAPITAL LETTER C WITH ACUTE */
    {    "C*", 0x039e },  /* Ξ GREEK CAPITAL LETTER XI */
    {    "C,", 0x00c7 },  /* Ç LATIN CAPITAL LETTER C WITH CEDILLA */
    {   "C,'", 0x1e08 },  /* Ḉ LATIN CAPITAL LETTER C WITH CEDILLA AND ACUTE */
    {   "C-o", 0x24b8 },  /* Ⓒ CIRCLED LATIN CAPITAL LETTER C */
    {    "C.", 0x010a },  /* Ċ LATIN CAPITAL LETTER C WITH DOT ABOVE */
    {    "C3", 0x0480 },  /* Ҁ CYRILLIC CAPITAL LETTER KOPPA */
    {    "C<", 0x010c },  /* Č LATIN CAPITAL LETTER C WITH CARON */
    {    "C=", 0x0426 },  /* Ц CYRILLIC CAPITAL LETTER TSE */
    {    "C>", 0x0108 },  /* Ĉ LATIN CAPITAL LETTER C WITH CIRCUMFLEX */
    {    "CC", 0x0094 },  /*   CANCEL CHARACTER (CCH) */
    {    "CG", 0x223e },  /* ∾ INVERTED LAZY S */
    {    "CI", 0x009b },  /*   CONTROL SEQUENCE INTRODUCER (CSI) */
    {    "CN", 0x0018 },  /*   CANCEL (CAN) */
    {    "CR", 0x000d },  /*   CARRIAGE RETURN (CR) */
    {    "Ca", 0x2038 },  /* ‸ CARET */
    {    "Ci", 0xe01c },  /*  CIRCLE (ISO-IR-83 0294) */
    {    "Co", 0x00a9 },  /* © COPYRIGHT SIGN */
    {    "Ct", 0x00a2 },  /* ¢ CENT SIGN */
    {    "Cu", 0x00a4 },  /* ¤ CURRENCY SIGN */
    {    "D%", 0x0402 },  /* Ђ CYRILLIC CAPITAL LETTER DJE (Serbocroatian) */
    {    "D*", 0x0394 },  /* Δ GREEK CAPITAL LETTER DELTA */
    {    "D+", 0x05d3 },  /* ד HEBREW LETTER DALET */
    {    "D,", 0x1e10 },  /* Ḑ LATIN CAPITAL LETTER D WITH CEDILLA */
    {    "D-", 0x00d0 },  /* Ð LATIN CAPITAL LETTER ETH (Icelandic) */
    {   "D-.", 0x1e0c },  /* Ḍ LATIN CAPITAL LETTER D WITH DOT BELOW */
    {   "D->", 0x1e12 },  /* Ḓ LATIN CAPITAL LETTER D WITH CIRCUMFLEX BELOW */
    {   "D-o", 0x24b9 },  /* Ⓓ CIRCLED LATIN CAPITAL LETTER D */
    {    "D.", 0x1e0a },  /* Ḋ LATIN CAPITAL LETTER D WITH DOT ABOVE */
    {    "D/", 0x0110 },  /* Đ LATIN CAPITAL LETTER D WITH STROKE */
    {    "D1", 0x0011 },  /*   DEVICE CONTROL ONE (DC1) */
    {    "D2", 0x0012 },  /*   DEVICE CONTROL TWO (DC2) */
    {    "D3", 0x0013 },  /*   DEVICE CONTROL THREE (DC3) */
    {    "D4", 0x0014 },  /*   DEVICE CONTROL FOUR (DC4) */
    {    "D<", 0x010e },  /* Ď LATIN CAPITAL LETTER D WITH CARON */
    {    "D=", 0x0414 },  /* Д CYRILLIC CAPITAL LETTER DE */
    {    "DC", 0x0090 },  /*   DEVICE CONTROL STRING (DCS) */
    {    "DE", 0x2206 },  /* ∆ INCREMENT */
    {    "DG", 0x00b0 },  /* ° DEGREE SIGN */
    {    "DH", 0x2533 },  /* ┳ BOX DRAWINGS HEAVY DOWN AND HORIZONTAL */
    {    "DI", 0x222c },  /* ∬ DOUBLE INTEGRAL */
    {    "DL", 0x0010 },  /*   DATALINK ESCAPE (DLE) */
    {   "DLr", 0x2531 },  /* ┱ BOX DRAWINGS RIGHT LIGHT AND LEFT DOWN HEAVY */
    {    "DO", 0x0024 },  /* $ DOLLAR SIGN */
    {    "DR", 0x250f },  /* ┏ BOX DRAWINGS HEAVY DOWN AND RIGHT */
    {    "DS", 0x0405 },  /* Ѕ CYRILLIC CAPITAL LETTER DZE (Macedonian) */
    {    "DT", 0x007f },  /*   DELETE (DEL) */
    {    "DZ", 0x040f },  /* Џ CYRILLIC CAPITAL LETTER DZHE */
    {    "D_", 0x1e0e },  /* Ḏ LATIN CAPITAL LETTER D WITH LINE BELOW */
    {    "Da", 0x30c0 },  /* ダ KATAKANA LETTER DA */
    {    "Db", 0x25c6 },  /* ◆ BLACK DIAMOND */
    {    "De", 0x30c7 },  /* デ KATAKANA LETTER DE */
    {    "Dh", 0x2530 },  /* ┰ BOX DRAWINGS DOWN HEAVY AND HORIZONTAL LIGHT */
    {    "Di", 0x30c2 },  /* ヂ KATAKANA LETTER DI */
    {    "Dl", 0x2512 },  /* ┒ BOX DRAWINGS DOWN HEAVY AND LEFT LIGHT */
    {   "DlR", 0x2532 },  /* ┲ BOX DRAWINGS LEFT LIGHT AND RIGHT DOWN HEAVY */
    {    "Do", 0x30c9 },  /* ド KATAKANA LETTER DO */
    {    "Dr", 0x250e },  /* ┎ BOX DRAWINGS DOWN HEAVY AND RIGHT LIGHT */
    {    "Dt", 0x25bc },  /* ▼ BLACK DOWN-POINTING TRIANGLE */
    {    "Du", 0x30c5 },  /* ヅ KATAKANA LETTER DU */
    {    "Dw", 0x25c7 },  /* ◇ WHITE DIAMOND */
    {    "E!", 0x00c8 },  /* È LATIN CAPITAL LETTER E WITH GRAVE */
    {    "E%", 0x0388 },  /* Έ GREEK CAPITAL LETTER EPSILON WITH ACUTE */
    {    "E'", 0x00c9 },  /* É LATIN CAPITAL LETTER E WITH ACUTE */
    {    "E(", 0x0114 },  /* Ĕ LATIN CAPITAL LETTER E WITH BREVE */
    {    "E*", 0x0395 },  /* Ε GREEK CAPITAL LETTER EPSILON */
    {    "E+", 0x05e2 },  /* ע HEBREW LETTER AYIN */
    {   "E,(", 0x1e1c },  /* Ḝ LATIN CAPITAL LETTER E WITH CEDILLA AND BREVE */
    {    "E-", 0x0112 },  /* Ē LATIN CAPITAL LETTER E WITH MACRON */
    {   "E-!", 0x1e14 },  /* Ḕ LATIN CAPITAL LETTER E WITH MACRON AND GRAVE */
    {   "E-'", 0x1e16 },  /* Ḗ LATIN CAPITAL LETTER E WITH MACRON AND ACUTE */
    {   "E-.", 0x1eb8 },  /* Ẹ LATIN CAPITAL LETTER E WITH DOT BELOW */
    {   "E->", 0x1e18 },  /* Ḙ LATIN CAPITAL LETTER E WITH CIRCUMFLEX BELOW */
    {   "E-?", 0x1e1a },  /* Ḛ LATIN CAPITAL LETTER E WITH TILDE BELOW */
    {   "E-o", 0x24ba },  /* Ⓔ CIRCLED LATIN CAPITAL LETTER E */
    {    "E.", 0x0116 },  /* Ė LATIN CAPITAL LETTER E WITH DOT ABOVE */
    {    "E2", 0x1eba },  /* Ẻ LATIN CAPITAL LETTER E WITH HOOK ABOVE */
    {    "E5", 0x3047 },  /* ぇ HIRAGANA LETTER SMALL E */
    {    "E6", 0x30a8 },  /* エ KATAKANA LETTER E */
    {    "E:", 0x00cb },  /* Ë LATIN CAPITAL LETTER E WITH DIAERESIS */
    {    "E;", 0x0118 },  /* Ę LATIN CAPITAL LETTER E WITH OGONEK */
    {    "E<", 0x011a },  /* Ě LATIN CAPITAL LETTER E WITH CARON */
    {    "E=", 0x0415 },  /* Е CYRILLIC CAPITAL LETTER IE */
    {    "E>", 0x00ca },  /* Ê LATIN CAPITAL LETTER E WITH CIRCUMFLEX */
    {   "E>!", 0x1ec0 },  /* Ề LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE */
    {   "E>'", 0x1ebe },  /* Ế LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE */
    {  "E>-.", 0x1ec6 },  /* Ệ LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND DOT BELOW */
    {   "E>2", 0x1ec2 },  /* Ể LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE */
    {   "E>?", 0x1ec4 },  /* Ễ LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND TILDE */
    {    "E?", 0x1ebc },  /* Ẽ LATIN CAPITAL LETTER E WITH TILDE */
    {    "EB", 0x0017 },  /*   END OF TRANSMISSION BLOCK (ETB) */
    {    "EC", 0x001b },  /*   ESCAPE (ESC) */
    {    "ED", 0x01b7 },  /* Ʒ LATIN CAPITAL LETTER EZH */
    {    "EG", 0x0097 },  /*   END OF GUARDED AREA (EPA) */
    {    "EM", 0x0019 },  /*   END OF MEDIUM (EM) */
    {    "EQ", 0x0005 },  /*   ENQUIRY (ENQ) */
    {    "ES", 0x0087 },  /*   END OF SELECTED AREA (ESA) */
    {    "ET", 0x0004 },  /*   END OF TRANSMISSION (EOT) */
    {    "EX", 0x0003 },  /*   END OF TEXT (ETX) */
    {    "EZ", 0x01ee },  /* Ǯ LATIN CAPITAL LETTER EZH WITH CARON */
    {    "Eh", 0x2302 },  /* ⌂ HOUSE */
    {    "F*", 0x03a6 },  /* Φ GREEK CAPITAL LETTER PHI */
    {   "F-o", 0x24bb },  /* Ⓕ CIRCLED LATIN CAPITAL LETTER F */
    {    "F.", 0x1e1e },  /* Ḟ LATIN CAPITAL LETTER F WITH DOT ABOVE */
    {    "F3", 0x0472 },  /* Ѳ CYRILLIC CAPITAL LETTER FITA */
    {    "F=", 0x0424 },  /* Ф CYRILLIC CAPITAL LETTER EF */
    {    "FA", 0x2200 },  /* ∀ FOR ALL */
    {    "FB", 0x2588 },  /* █ FULL BLOCK */
    {    "FD", 0x2571 },  /* ╱ BOX DRAWINGS LIGHT DIAGONAL UPPER RIGHT TO LOWER LEFT */
    {    "FF", 0x000c },  /*   FORM FEED (FF) */
    {    "FS", 0x001c },  /*   FILE SEPARATOR (IS4) */
    {    "Fd", 0x25e2 },  /* ◢ BLACK LOWER RIGHT TRIANGLE */
    {    "Fl", 0xe023 },  /*  DUTCH GUILDER SIGN (IBM437 159) */
    {    "Fm", 0x2640 },  /* ♀ FEMALE SIGN */
    {    "G%", 0x0403 },  /* Ѓ CYRILLIC CAPITAL LETTER GJE (Macedonian) */
    {    "G'", 0x01f4 },  /* Ǵ LATIN CAPITAL LETTER G WITH ACUTE */
    {    "G(", 0x011e },  /* Ğ LATIN CAPITAL LETTER G WITH BREVE */
    {    "G*", 0x0393 },  /* Γ GREEK CAPITAL LETTER GAMMA */
    {    "G+", 0x05d2 },  /* ג HEBREW LETTER GIMEL */
    {    "G,", 0x0122 },  /* Ģ LATIN CAPITAL LETTER G WITH CEDILLA */
    {    "G-", 0x1e20 },  /* Ḡ LATIN CAPITAL LETTER G WITH MACRON */
    {   "G-o", 0x24bc },  /* Ⓖ CIRCLED LATIN CAPITAL LETTER G */
    {    "G.", 0x0120 },  /* Ġ LATIN CAPITAL LETTER G WITH DOT ABOVE */
    {    "G/", 0x01e4 },  /* Ǥ LATIN CAPITAL LETTER G WITH STROKE */
    {    "G3", 0x0490 },  /* Ґ CYRILLIC CAPITAL LETTER GHE WITH UPTURN */
    {    "G<", 0x01e6 },  /* Ǧ LATIN CAPITAL LETTER G WITH CARON */
    {    "G=", 0x0413 },  /* Г CYRILLIC CAPITAL LETTER GHE */
    {    "G>", 0x011c },  /* Ĝ LATIN CAPITAL LETTER G WITH CIRCUMFLEX */
    {    "GC", 0x0099 },  /*   SINGLE GRAPHIC CHARACTER INTRODUCER (SGCI) */
    {    "GF", 0xe024 },  /*  GAMMA FUNCTION SIGN (ISO-10646-1DIS 032/032/037/122) */
    {    "GS", 0x001d },  /*   GROUP SEPARATOR (IS3) */
    {    "Ga", 0x30ac },  /* ガ KATAKANA LETTER GA */
    {    "Ge", 0x30b2 },  /* ゲ KATAKANA LETTER GE */
    {    "Gi", 0x30ae },  /* ギ KATAKANA LETTER GI */
    {    "Go", 0x30b4 },  /* ゴ KATAKANA LETTER GO */
    {    "Gu", 0x30b0 },  /* グ KATAKANA LETTER GU */
    {    "H'", 0x0621 },  /* ء ARABIC LETTER HAMZA */
    {    "H*", 0x0398 },  /* Θ GREEK CAPITAL LETTER THETA */
    {    "H+", 0x05d4 },  /* ה HEBREW LETTER HE */
    {    "H,", 0x1e28 },  /* Ḩ LATIN CAPITAL LETTER H WITH CEDILLA */
    {   "H-(", 0x1e2a },  /* Ḫ LATIN CAPITAL LETTER H WITH BREVE BELOW */
    {   "H-.", 0x1e24 },  /* Ḥ LATIN CAPITAL LETTER H WITH DOT BELOW */
    {   "H-o", 0x24bd },  /* Ⓗ CIRCLED LATIN CAPITAL LETTER H */
    {    "H.", 0x1e22 },  /* Ḣ LATIN CAPITAL LETTER H WITH DOT ABOVE */
    {    "H/", 0x0126 },  /* Ħ LATIN CAPITAL LETTER H WITH STROKE */
    {    "H:", 0x1e26 },  /* Ḧ LATIN CAPITAL LETTER H WITH DIAERESIS */
    {    "H=", 0x0425 },  /* Х CYRILLIC CAPITAL LETTER HA */
    {    "H>", 0x0124 },  /* Ĥ LATIN CAPITAL LETTER H WITH CIRCUMFLEX */
    {    "HH", 0x2501 },  /* ━ BOX DRAWINGS HEAVY HORIZONTAL */
    {    "HI", 0x2253 },  /* ≓ IMAGE OF OR APPROXIMATELY EQUAL TO */
    {    "HJ", 0x0089 },  /*   CHARACTER TABULATION WITH JUSTIFICATION (HTJ) */
    {    "HO", 0x0081 },  /*   HIGH OCTET PRESET (HOP) */
    {    "HS", 0x0088 },  /*   CHARACTER TABULATION SET (HTS) */
    {    "HT", 0x0009 },  /*   CHARACTER TABULATION (HT) */
    {    "Ha", 0x30cf },  /* ハ KATAKANA LETTER HA */
    {    "He", 0x30d8 },  /* ヘ KATAKANA LETTER HE */
    {    "Hi", 0x30d2 },  /* ヒ KATAKANA LETTER HI */
    {    "Ho", 0x30db },  /* ホ KATAKANA LETTER HO */
    {    "Hu", 0x30d5 },  /* フ KATAKANA LETTER HU */
    {    "I!", 0x00cc },  /* Ì LATIN CAPITAL LETTER I WITH GRAVE */
    {    "I%", 0x038a },  /* Ί GREEK CAPITAL LETTER IOTA WITH ACUTE */
    {    "I'", 0x00cd },  /* Í LATIN CAPITAL LETTER I WITH ACUTE */
    {    "I(", 0x012c },  /* Ĭ LATIN CAPITAL LETTER I WITH BREVE */
    {    "I*", 0x0399 },  /* Ι GREEK CAPITAL LETTER IOTA */
    {    "I-", 0x012a },  /* Ī LATIN CAPITAL LETTER I WITH MACRON */
    {   "I-.", 0x1eca },  /* Ị LATIN CAPITAL LETTER I WITH DOT BELOW */
    {   "I-?", 0x1e2c },  /* Ḭ LATIN CAPITAL LETTER I WITH TILDE BELOW */
    {   "I-o", 0x24be },  /* Ⓘ CIRCLED LATIN CAPITAL LETTER I */
    {    "I.", 0x0130 },  /* İ LATIN CAPITAL LETTER I WITH DOT ABOVE */
    {    "I2", 0x1ec8 },  /* Ỉ LATIN CAPITAL LETTER I WITH HOOK ABOVE */
    {    "I5", 0x3043 },  /* ぃ HIRAGANA LETTER SMALL I */
    {    "I6", 0x30a4 },  /* イ KATAKANA LETTER I */
    {    "I:", 0x00cf },  /* Ï LATIN CAPITAL LETTER I WITH DIAERESIS */
    {   "I:'", 0x1e2e },  /* Ḯ LATIN CAPITAL LETTER I WITH DIAERESIS AND ACUTE */
    {    "I;", 0x012e },  /* Į LATIN CAPITAL LETTER I WITH OGONEK */
    {    "I<", 0x01cf },  /* Ǐ LATIN CAPITAL LETTER I WITH CARON */
    {    "I=", 0x0418 },  /* И CYRILLIC CAPITAL LETTER I */
    {    "I>", 0x00ce },  /* Î LATIN CAPITAL LETTER I WITH CIRCUMFLEX */
    {    "I?", 0x0128 },  /* Ĩ LATIN CAPITAL LETTER I WITH TILDE */
    {    "IE", 0x0404 },  /* Є CYRILLIC CAPITAL LETTER UKRAINIAN IE */
    {    "II", 0x0406 },  /* І CYRILLIC CAPITAL LETTER BYELORUSSIAN-UKRAINIAN I */
    {    "IJ", 0x0132 },  /* Ĳ LATIN CAPITAL LIGATURE IJ */
    {    "IN", 0x0084 },  /*   INDEX (IND) */
    {    "IO", 0x0401 },  /* Ё CYRILLIC CAPITAL LETTER IO */
    {    "IS", 0x3000 },  /* 　 IDEOGRAPHIC SPACE */
    {    "Ic", 0x25d9 },  /* ◙ INVERSE WHITE CIRCLE */
    {    "Il", 0x2321 },  /* ⌡ BOTTOM HALF INTEGRAL */
    {    "In", 0x222b },  /* ∫ INTEGRAL */
    {    "Io", 0x222e },  /* ∮ CONTOUR INTEGRAL */
    {    "Iu", 0x2320 },  /* ⌠ TOP HALF INTEGRAL */
    {    "J%", 0x0408 },  /* Ј CYRILLIC CAPITAL LETTER JE */
    {    "J*", 0x03aa },  /* Ϊ GREEK CAPITAL LETTER IOTA WITH DIAERESIS */
    {    "J+", 0x05d9 },  /* י HEBREW LETTER YOD */
    {   "J-o", 0x24bf },  /* Ⓙ CIRCLED LATIN CAPITAL LETTER J */
    {    "J<", 0xe028 },  /*  LATIN CAPITAL LETTER J WITH CARON (lowercase: */
    {    "J=", 0x0419 },  /* Й CYRILLIC CAPITAL LETTER SHORT I */
    {    "J>", 0x0134 },  /* Ĵ LATIN CAPITAL LETTER J WITH CIRCUMFLEX */
    {    "JA", 0x042f },  /* Я CYRILLIC CAPITAL LETTER YA */
    {    "JE", 0x042d },  /* Э CYRILLIC CAPITAL LETTER E */
    {    "JU", 0x042e },  /* Ю CYRILLIC CAPITAL LETTER YU */
    {  "June", 0x1992 },  /* ᦒ  */
    {    "K%", 0x05da },  /* ך HEBREW LETTER FINAL KAF */
    {    "K'", 0x1e30 },  /* Ḱ LATIN CAPITAL LETTER K WITH ACUTE */
    {    "K*", 0x039a },  /* Κ GREEK CAPITAL LETTER KAPPA */
    {    "K+", 0x05db },  /* כ HEBREW LETTER KAF */
    {    "K,", 0x0136 },  /* Ķ LATIN CAPITAL LETTER K WITH CEDILLA */
    {   "K-.", 0x1e32 },  /* Ḳ LATIN CAPITAL LETTER K WITH DOT BELOW */
    {   "K-o", 0x24c0 },  /* Ⓚ CIRCLED LATIN CAPITAL LETTER K */
    {    "K3", 0x03de },  /* Ϟ GREEK CAPITAL LETTER KOPPA */
    {    "K<", 0x01e8 },  /* Ǩ LATIN CAPITAL LETTER K WITH CARON */
    {    "K=", 0x041a },  /* К CYRILLIC CAPITAL LETTER KA */
    {    "KA", 0x30f5 },  /* ヵ KATAKANA LETTER SMALL KA */
    {    "KE", 0x30f6 },  /* ヶ KATAKANA LETTER SMALL KE */
    {    "KJ", 0x040c },  /* Ќ CYRILLIC CAPITAL LETTER KJE (Macedonian) */
    {   "KSC", 0x327f },  /* ㉿ KOREAN STANDARD SYMBOL */
    {    "K_", 0x1e34 },  /* Ḵ LATIN CAPITAL LETTER K WITH LINE BELOW */
    {    "Ka", 0x30ab },  /* カ KATAKANA LETTER KA */
    {    "Ke", 0x30b1 },  /* ケ KATAKANA LETTER KE */
    {    "Ki", 0x30ad },  /* キ KATAKANA LETTER KI */
    {    "Ko", 0x30b3 },  /* コ KATAKANA LETTER KO */
    {    "Ku", 0x30af },  /* ク KATAKANA LETTER KU */
    {    "L'", 0x0139 },  /* Ĺ LATIN CAPITAL LETTER L WITH ACUTE */
    {    "L*", 0x039b },  /* Λ GREEK CAPITAL LETTER LAMDA */
    {    "L+", 0x05dc },  /* ל HEBREW LETTER LAMED */
    {    "L,", 0x013b },  /* Ļ LATIN CAPITAL LETTER L WITH CEDILLA */
    {  "L--.", 0x1e38 },  /* Ḹ LATIN CAPITAL LETTER L WITH DOT BELOW AND MACRON */
    {   "L-.", 0x1e36 },  /* Ḷ LATIN CAPITAL LETTER L WITH DOT BELOW */
    {   "L->", 0x1e3c },  /* Ḽ LATIN CAPITAL LETTER L WITH CIRCUMFLEX BELOW */
    {   "L-o", 0x24c1 },  /* Ⓛ CIRCLED LATIN CAPITAL LETTER L */
    {    "L.", 0x013f },  /* Ŀ LATIN CAPITAL LETTER L WITH MIDDLE DOT */
    {    "L/", 0x0141 },  /* Ł LATIN CAPITAL LETTER L WITH STROKE */
    {    "L<", 0x013d },  /* Ľ LATIN CAPITAL LETTER L WITH CARON */
    {    "L=", 0x041b },  /* Л CYRILLIC CAPITAL LETTER EL */
    {    "LB", 0x2584 },  /* ▄ LOWER HALF BLOCK */
    {    "LD", 0x2513 },  /* ┓ BOX DRAWINGS HEAVY DOWN AND LEFT */
    {    "LF", 0x000a },  /*   LINE FEED (LF) */
    {    "LJ", 0x0409 },  /* Љ CYRILLIC CAPITAL LETTER LJE */
    {    "LZ", 0x25ca },  /* ◊ LOZENGE */
    {    "L_", 0x1e3a },  /* Ḻ LATIN CAPITAL LETTER L WITH LINE BELOW */
    {    "Li", 0x20a4 },  /* ₤ LIRA SIGN */
    {    "M%", 0x05dd },  /* ם HEBREW LETTER FINAL MEM */
    {    "M'", 0x1e3e },  /* Ḿ LATIN CAPITAL LETTER M WITH ACUTE */
    {    "M*", 0x039c },  /* Μ GREEK CAPITAL LETTER MU */
    {    "M+", 0x05de },  /* מ HEBREW LETTER MEM */
    {   "M-.", 0x1e42 },  /* Ṃ LATIN CAPITAL LETTER M WITH DOT BELOW */
    {   "M-o", 0x24c2 },  /* Ⓜ CIRCLED LATIN CAPITAL LETTER M */
    {    "M.", 0x1e40 },  /* Ṁ LATIN CAPITAL LETTER M WITH DOT ABOVE */
    {   "M16", 0x266c },  /* ♬ BARRED SIXTEENTH NOTES */
    {    "M2", 0x266b },  /* ♫ BARRED EIGHTH NOTES */
    {    "M3", 0x03dc },  /* Ϝ GREEK CAPITAL LETTER DIGAMMA */
    {    "M8", 0x266a },  /* ♪ EIGHTH NOTE */
    {    "M=", 0x041c },  /* М CYRILLIC CAPITAL LETTER EM */
    {    "MW", 0x0095 },  /*   MESSAGE WAITING (MW) */
    {    "MX", 0x266f },  /* ♯ MUSIC SHARP SIGN */
    {    "Ma", 0x30de },  /* マ KATAKANA LETTER MA */
    {    "Mb", 0x266d },  /* ♭ MUSIC FLAT SIGN */
    {    "Md", 0x2669 },  /* ♩ QUARTER NOTE */
    {    "Me", 0x30e1 },  /* メ KATAKANA LETTER ME */
    {    "Mi", 0x30df },  /* ミ KATAKANA LETTER MI */
    {    "Ml", 0x2642 },  /* ♂ MALE SIGN */
    {    "Mo", 0x30e2 },  /* モ KATAKANA LETTER MO */
    {    "Mu", 0x30e0 },  /* ム KATAKANA LETTER MU */
    {    "Mx", 0x266e },  /* ♮ MUSIC NATURAL SIGN */
    {    "My", 0x00b5 },  /* µ MICRO SIGN */
    {    "N%", 0x05df },  /* ן HEBREW LETTER FINAL NUN */
    {    "N'", 0x0143 },  /* Ń LATIN CAPITAL LETTER N WITH ACUTE */
    {    "N*", 0x039d },  /* Ν GREEK CAPITAL LETTER NU */
    {    "N+", 0x05e0 },  /* נ HEBREW LETTER NUN */
    {    "N,", 0x0145 },  /* Ņ LATIN CAPITAL LETTER N WITH CEDILLA */
    {   "N-.", 0x1e46 },  /* Ṇ LATIN CAPITAL LETTER N WITH DOT BELOW */
    {   "N->", 0x1e4a },  /* Ṋ LATIN CAPITAL LETTER N WITH CIRCUMFLEX BELOW */
    {   "N->", 0x1e4b },  /* ṋ LATIN SMALL LETTER N WITH CIRCUMFLEX BELOW */
    {   "N-o", 0x24c3 },  /* Ⓝ CIRCLED LATIN CAPITAL LETTER N */
    {    "N.", 0x1e44 },  /* Ṅ LATIN CAPITAL LETTER N WITH DOT ABOVE */
    {    "N0", 0x2116 },  /* № NUMERO SIGN */
    {    "N6", 0x30f3 },  /* ン KATAKANA LETTER N */
    {    "N<", 0x0147 },  /* Ň LATIN CAPITAL LETTER N WITH CARON */
    {    "N=", 0x041d },  /* Н CYRILLIC CAPITAL LETTER EN */
    {    "N?", 0x00d1 },  /* Ñ LATIN CAPITAL LETTER N WITH TILDE */
    {    "NB", 0x2207 },  /* ∇ NABLA */
    {    "NG", 0x014a },  /* Ŋ LATIN CAPITAL LETTER ENG (Lappish) */
    {    "NH", 0x0083 },  /*   NO BREAK HERE (NBH) */
    {    "NI", 0x2310 },  /* ⌐ REVERSED NOT SIGN */
    {    "NJ", 0x040a },  /* Њ CYRILLIC CAPITAL LETTER NJE */
    {    "NK", 0x0015 },  /*   NEGATIVE ACKNOWLEDGE (NAK) */
    {    "NL", 0x0085 },  /*   NEXT LINE (NEL) */
    {    "NO", 0x00ac },  /* ¬ NOT SIGN */
    {    "NS", 0x00a0 },  /*   NO-BREAK SPACE */
    {    "NU", 0x0000 },  /*   NULL (NUL) */
    {    "N_", 0x1e48 },  /* Ṉ LATIN CAPITAL LETTER N WITH LINE BELOW */
    {    "Na", 0x30ca },  /* ナ KATAKANA LETTER NA */
    {    "Nb", 0x0023 },  /* # NUMBER SIGN */
    {    "Ne", 0x30cd },  /* ネ KATAKANA LETTER NE */
    {    "Ni", 0x30cb },  /* ニ KATAKANA LETTER NI */
    {    "No", 0x30ce },  /* ノ KATAKANA LETTER NO */
    {    "Nu", 0x30cc },  /* ヌ KATAKANA LETTER NU */
    {    "O!", 0x00d2 },  /* Ò LATIN CAPITAL LETTER O WITH GRAVE */
    {   "O\"", 0x0150 },  /* Ő LATIN CAPITAL LETTER O WITH DOUBLE ACUTE */
    {    "O%", 0x038c },  /* Ό GREEK CAPITAL LETTER OMICRON WITH ACUTE */
    {    "O'", 0x00d3 },  /* Ó LATIN CAPITAL LETTER O WITH ACUTE */
    {    "O(", 0x014e },  /* Ŏ LATIN CAPITAL LETTER O WITH BREVE */
    {    "O*", 0x039f },  /* Ο GREEK CAPITAL LETTER OMICRON */
    {    "O-", 0x014c },  /* Ō LATIN CAPITAL LETTER O WITH MACRON */
    {   "O-!", 0x1e50 },  /* Ṑ LATIN CAPITAL LETTER O WITH MACRON AND GRAVE */
    {   "O-'", 0x1e52 },  /* Ṓ LATIN CAPITAL LETTER O WITH MACRON AND ACUTE */
    {   "O-.", 0x1ecc },  /* Ọ LATIN CAPITAL LETTER O WITH DOT BELOW */
    {   "O-o", 0x24c4 },  /* Ⓞ CIRCLED LATIN CAPITAL LETTER O */
    {    "O/", 0x00d8 },  /* Ø LATIN CAPITAL LETTER O WITH STROKE */
    {   "O/'", 0x01fe },  /* Ǿ LATIN CAPITAL LETTER O WITH STROKE AND ACUTE */
    {    "O1", 0x01ec },  /* Ǭ LATIN CAPITAL LETTER O WITH OGONEK AND MACRON */
    {    "O2", 0x1ece },  /* Ỏ LATIN CAPITAL LETTER O WITH HOOK ABOVE */
    {    "O3", 0x046a },  /* Ѫ CYRILLIC CAPITAL LETTER BIG YUS */
    {    "O5", 0x3049 },  /* ぉ HIRAGANA LETTER SMALL O */
    {    "O6", 0x30aa },  /* オ KATAKANA LETTER O */
    {    "O9", 0x01a0 },  /* Ơ LATIN CAPITAL LETTER O WITH HORN */
    {   "O9!", 0x1edc },  /* Ờ LATIN CAPITAL LETTER O WITH HORN AND GRAVE */
    {   "O9'", 0x1eda },  /* Ớ LATIN CAPITAL LETTER O WITH HORN AND ACUTE */
    {  "O9-.", 0x1ee2 },  /* Ợ LATIN CAPITAL LETTER O WITH HORN AND DOT BELOW */
    {   "O92", 0x1ede },  /* Ở LATIN CAPITAL LETTER O WITH HORN AND HOOK ABOVE */
    {   "O9?", 0x1ee0 },  /* Ỡ LATIN CAPITAL LETTER O WITH HORN AND TILDE */
    {    "O:", 0x00d6 },  /* Ö LATIN CAPITAL LETTER O WITH DIAERESIS */
    {    "O;", 0x01ea },  /* Ǫ LATIN CAPITAL LETTER O WITH OGONEK */
    {    "O<", 0x01d1 },  /* Ǒ LATIN CAPITAL LETTER O WITH CARON */
    {    "O=", 0x041e },  /* О CYRILLIC CAPITAL LETTER O */
    {    "O>", 0x00d4 },  /* Ô LATIN CAPITAL LETTER O WITH CIRCUMFLEX */
    {   "O>!", 0x1ed2 },  /* Ồ LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND GRAVE */
    {   "O>'", 0x1ed0 },  /* Ố LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND ACUTE */
    {  "O>-.", 0x1ed8 },  /* Ộ LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND DOT BELOW */
    {   "O>2", 0x1ed4 },  /* Ổ LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE */
    {   "O>?", 0x1ed6 },  /* Ỗ LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND TILDE */
    {    "O?", 0x00d5 },  /* Õ LATIN CAPITAL LETTER O WITH TILDE */
    {   "O?'", 0x1e4c },  /* Ṍ LATIN CAPITAL LETTER O WITH TILDE AND ACUTE */
    {   "O?:", 0x1e4e },  /* Ṏ LATIN CAPITAL LETTER O WITH TILDE AND DIAERESIS */
    {    "OC", 0x009d },  /*   OPERATING SYSTEM COMMAND (OSC) */
    {    "OE", 0x0152 },  /* Œ LATIN CAPITAL LIGATURE OE */
    {    "OI", 0x01a2 },  /* Ƣ LATIN CAPITAL LETTER OI */
    {    "OK", 0x2713 },  /* ✓ CHECK MARK */
    {    "OR", 0x2228 },  /* ∨ LOGICAL OR */
    {    "OS", 0x25a1 },  /* □ WHITE SQUARE */
    {    "Ob", 0x2218 },  /* ∘ RING OPERATOR */
    {    "Om", 0x2126 },  /* Ω OHM SIGN */
    {    "Or", 0x25ad },  /* ▭ WHITE RECTANGLE */
    {    "P%", 0x05e3 },  /* ף HEBREW LETTER FINAL PE */
    {    "P'", 0x1e54 },  /* Ṕ LATIN CAPITAL LETTER P WITH ACUTE */
    {    "P*", 0x03a0 },  /* Π GREEK CAPITAL LETTER PI */
    {    "P+", 0x05e4 },  /* פ HEBREW LETTER PE */
    {   "P-o", 0x24c5 },  /* Ⓟ CIRCLED LATIN CAPITAL LETTER P */
    {    "P.", 0x1e56 },  /* Ṗ LATIN CAPITAL LETTER P WITH DOT ABOVE */
    {    "P1", 0x0091 },  /*   PRIVATE USE ONE (PU1) */
    {    "P2", 0x0092 },  /*   PRIVATE USE TWO (PU2) */
    {    "P3", 0x03e0 },  /* Ϡ GREEK CAPITAL LETTER SAMPI */
    {    "P=", 0x041f },  /* П CYRILLIC CAPITAL LETTER PE */
    {    "PA", 0x0080 },  /*   PADDING CHARACTER (PAD) */
    {    "PD", 0x008b },  /*   PARTIAL LINE FORWARD (PLD) */
    {    "PI", 0x00b6 },  /* ¶ PILCROW SIGN */
    {    "PL", 0x25c0 },  /* ◀ BLACK LEFT-POINTING TRIANGLE */
    {    "PM", 0x009e },  /*   PRIVACY MESSAGE (PM) */
    {    "PO", 0x2117 },  /* ℗ SOUND RECORDING COPYRIGHT */
    {    "PP", 0x2225 },  /* ∥ PARALLEL TO */
    {    "PR", 0x25b6 },  /* ▶ BLACK RIGHT-POINTING TRIANGLE */
    {    "PU", 0x008c },  /*   PARTIAL LINE BACKWARD (PLU) */
    {    "Pa", 0x30d1 },  /* パ KATAKANA LETTER PA */
    {    "Pd", 0x00a3 },  /* £ POUND SIGN */
    {    "Pe", 0x30da },  /* ペ KATAKANA LETTER PE */
    {    "Pi", 0x30d4 },  /* ピ KATAKANA LETTER PI */
    {    "Po", 0x30dd },  /* ポ KATAKANA LETTER PO */
    {    "Pt", 0x20a7 },  /* ₧ PESETA SIGN */
    {    "Pu", 0x30d7 },  /* プ KATAKANA LETTER PU */
    {    "Q*", 0x03a8 },  /* Ψ GREEK CAPITAL LETTER PSI */
    {    "Q+", 0x05e7 },  /* ק HEBREW LETTER QOF */
    {   "Q-o", 0x24c6 },  /* Ⓠ CIRCLED LATIN CAPITAL LETTER Q */
    {    "R'", 0x0154 },  /* Ŕ LATIN CAPITAL LETTER R WITH ACUTE */
    {    "R*", 0x03a1 },  /* Ρ GREEK CAPITAL LETTER RHO */
    {    "R+", 0x05e8 },  /* ר HEBREW LETTER RESH */
    {    "R,", 0x0156 },  /* Ŗ LATIN CAPITAL LETTER R WITH CEDILLA */
    {  "R--.", 0x1e5c },  /* Ṝ LATIN CAPITAL LETTER R WITH DOT BELOW AND MACRON */
    {   "R-.", 0x1e5a },  /* Ṛ LATIN CAPITAL LETTER R WITH DOT BELOW */
    {   "R-o", 0x24c7 },  /* Ⓡ CIRCLED LATIN CAPITAL LETTER R */
    {    "R.", 0x1e58 },  /* Ṙ LATIN CAPITAL LETTER R WITH DOT ABOVE */
    {    "R<", 0x0158 },  /* Ř LATIN CAPITAL LETTER R WITH CARON */
    {    "R=", 0x0420 },  /* Р CYRILLIC CAPITAL LETTER ER */
    {    "RB", 0x2590 },  /* ▐ RIGHT HALF BLOCK */
    {    "RF", 0x25a4 },  /* ▤ SQUARE WITH HORIZONTAL FILL */
    {    "RH", 0x25a6 },  /* ▦ SQUARE WITH ORTHOGONAL CROSSHATCH FILL */
    {    "RI", 0x008d },  /*   REVERSE LINE FEED (RI) */
    {    "RK", 0x25a8 },  /* ▨ SQUARE WITH UPPER RIGHT TO LOWER LEFT FILL */
    {    "RO", 0x25a2 },  /* ▢ WHITE SQUARE WITH ROUNDED CORNERS */
    {    "RS", 0x001e },  /*   RECORD SEPARATOR (IS2) */
    {    "RT", 0x221a },  /* √ SQUARE ROOT */
    {    "RX", 0x25a9 },  /* ▩ SQUARE WITH DIAGONAL CROSSHATCH FILL */
    {    "RY", 0x25a5 },  /* ▥ SQUARE WITH VERTICAL FILL */
    {    "RZ", 0x25a7 },  /* ▧ SQUARE WITH UPPER LEFT TO LOWER RIGHT FILL */
    {    "R_", 0x1e5e },  /* Ṟ LATIN CAPITAL LETTER R WITH LINE BELOW */
    {    "Ra", 0x30e9 },  /* ラ KATAKANA LETTER RA */
    {    "Re", 0x30ec },  /* レ KATAKANA LETTER RE */
    {    "Rg", 0x00ae },  /* ® REGISTERED SIGN */
    {    "Ri", 0x30ea },  /* リ KATAKANA LETTER RI */
    {    "Ro", 0x30ed },  /* ロ KATAKANA LETTER RO */
    {    "Rr", 0x25a3 },  /* ▣ WHITE SQUARE CONTAINING BLACK SMALL SQUARE */
    {    "Ru", 0x30eb },  /* ル KATAKANA LETTER RU */
    {    "Rx", 0x211e },  /* ℞ PRESCRIPTION TAKE */
    {    "S%", 0x0428 },  /* Ш CYRILLIC CAPITAL LETTER SHA */
    {    "S'", 0x015a },  /* Ś LATIN CAPITAL LETTER S WITH ACUTE */
    {   "S'.", 0x1e64 },  /* Ṥ LATIN CAPITAL LETTER S WITH ACUTE AND DOT ABOVE */
    {    "S*", 0x03a3 },  /* Σ GREEK CAPITAL LETTER SIGMA */
    {    "S+", 0x05e1 },  /* ס HEBREW LETTER SAMEKH */
    {    "S,", 0x015e },  /* Ş LATIN CAPITAL LETTER S WITH CEDILLA */
    {   "S-.", 0x1e62 },  /* Ṣ LATIN CAPITAL LETTER S WITH DOT BELOW */
    {   "S-o", 0x24c8 },  /* Ⓢ CIRCLED LATIN CAPITAL LETTER S */
    {    "S.", 0x1e60 },  /* Ṡ LATIN CAPITAL LETTER S WITH DOT ABOVE */
    {  "S.-.", 0x1e68 },  /* Ṩ LATIN CAPITAL LETTER S WITH DOT BELOW AND DOT ABOVE */
    {  "S.-.", 0x1e69 },  /* ṩ LATIN SMALL LETTER S WITH DOT BELOW AND DOT ABOVE */
    {    "S2", 0x008e },  /*   SINGLE-SHIFT TWO (SS2) */
    {    "S3", 0x008f },  /*   SINGLE-SHIFT THREE (SS3) */
    {    "S<", 0x0160 },  /* Š LATIN CAPITAL LETTER S WITH CARON */
    {   "S<.", 0x1e66 },  /* Ṧ LATIN CAPITAL LETTER S WITH CARON AND DOT ABOVE */
    {    "S=", 0x0421 },  /* С CYRILLIC CAPITAL LETTER ES */
    {    "S>", 0x015c },  /* Ŝ LATIN CAPITAL LETTER S WITH CIRCUMFLEX */
    {    "SA", 0x0086 },  /*   START OF SELECTED AREA (SSA) */
    {    "SB", 0x001a },  /*   SUBSTITUTE (SUB) */
    {    "SC", 0x009a },  /*   SINGLE CHARACTER INTRODUCER (SCI) */
    {    "SE", 0x00a7 },  /* § SECTION SIGN */
    {    "SG", 0x0096 },  /*   START OF GUARDED AREA (SPA) */
    {    "SH", 0x0001 },  /*   START OF HEADING (SOH) */
    {    "SI", 0x000f },  /*   SHIFT IN (SI) */
    {    "SM", 0x2120 },  /* ℠ SERVICE MARK */
    {    "SO", 0x000e },  /*   SHIFT OUT (SO) */
    {    "SP", 0x0020 },  /*   SPACE */
    {    "SR", 0x25ac },  /* ▬ BLACK RECTANGLE */
    {    "SS", 0x0098 },  /*   START OF STRING (SOS) */
    {    "ST", 0x009c },  /*   STRING TERMINATOR (ST) */
    {    "SU", 0x263c },  /* ☼ WHITE SUN WITH RAYS */
    {    "SX", 0x0002 },  /*   START OF TEXT (STX) */
    {    "SY", 0x0016 },  /*   SYNCRONOUS IDLE (SYN) */
    {    "Sa", 0x30b5 },  /* サ KATAKANA LETTER SA */
    {    "Sb", 0x2219 },  /* ∙ BULLET OPERATOR */
    {    "Sc", 0x0429 },  /* Щ CYRILLIC CAPITAL LETTER SHCHA */
    {    "Se", 0x30bb },  /* セ KATAKANA LETTER SE */
    {    "Sh", 0x05e9 },  /* ש HEBREW LETTER SHIN */
    {    "Si", 0x30b7 },  /* シ KATAKANA LETTER SI */
    {    "Sn", 0x25d8 },  /* ◘ INVERSE BULLET */
    {    "So", 0x30bd },  /* ソ KATAKANA LETTER SO */
    {    "Su", 0x30b9 },  /* ス KATAKANA LETTER SU */
    {    "T*", 0x03a4 },  /* Τ GREEK CAPITAL LETTER TAU */
    {    "T+", 0x05ea },  /* ת HEBREW LETTER TAV */
    {    "T,", 0x0162 },  /* Ţ LATIN CAPITAL LETTER T WITH CEDILLA */
    {   "T-.", 0x1e6c },  /* Ṭ LATIN CAPITAL LETTER T WITH DOT BELOW */
    {   "T->", 0x1e70 },  /* Ṱ LATIN CAPITAL LETTER T WITH CIRCUMFLEX BELOW */
    {   "T-o", 0x24c9 },  /* Ⓣ CIRCLED LATIN CAPITAL LETTER T */
    {    "T.", 0x1e6a },  /* Ṫ LATIN CAPITAL LETTER T WITH DOT ABOVE */
    {    "T/", 0x0166 },  /* Ŧ LATIN CAPITAL LETTER T WITH STROKE */
    {    "T3", 0x03da },  /* Ϛ GREEK CAPITAL LETTER STIGMA */
    {    "T<", 0x0164 },  /* Ť LATIN CAPITAL LETTER T WITH CARON */
    {    "T=", 0x0422 },  /* Т CYRILLIC CAPITAL LETTER TE */
    {    "TB", 0x2580 },  /* ▀ UPPER HALF BLOCK */
    {    "TE", 0x2203 },  /* ∃ THERE EXISTS */
    {   "TEL", 0x260e },  /* ☎ BLACK TELEPHONE */
    {    "TH", 0x00de },  /* Þ LATIN CAPITAL LETTER THORN (Icelandic) */
    {    "TM", 0x2122 },  /* ™ TRADE MARK SIGN */
    {    "TR", 0x2315 },  /* ⌕ TELEPHONE RECORDER */
    {    "TS", 0x0093 },  /*   SET TRANSMIT STATE (STS) */
    {    "TU", 0x30c3 },  /* ッ KATAKANA LETTER SMALL TU */
    {    "T_", 0x1e6e },  /* Ṯ LATIN CAPITAL LETTER T WITH LINE BELOW */
    {    "Ta", 0x30bf },  /* タ KATAKANA LETTER TA */
    {    "Te", 0x30c6 },  /* テ KATAKANA LETTER TE */
    {   "Tel", 0xe021 },  /*  TEL COMPATIBILITY SIGN (ISO-IR-149 0269) */
    {    "Ti", 0x30c1 },  /* チ KATAKANA LETTER TI */
    {    "Tj", 0x05d8 },  /* ט HEBREW LETTER TET */
    {    "Tl", 0x25c1 },  /* ◁ WHITE LEFT-POINTING TRIANGLE */
    {    "To", 0x30c8 },  /* ト KATAKANA LETTER TO */
    {    "Tr", 0x25b7 },  /* ▷ WHITE RIGHT-POINTING TRIANGLE */
    {    "Ts", 0x040b },  /* Ћ CYRILLIC CAPITAL LETTER TSHE (Serbocroatian) */
    {    "Tu", 0x30c4 },  /* ツ KATAKANA LETTER TU */
    {    "U!", 0x00d9 },  /* Ù LATIN CAPITAL LETTER U WITH GRAVE */
    {   "U\"", 0x0170 },  /* Ű LATIN CAPITAL LETTER U WITH DOUBLE ACUTE */
    {    "U%", 0x038e },  /* Ύ GREEK CAPITAL LETTER UPSILON WITH ACUTE */
    {    "U'", 0x00da },  /* Ú LATIN CAPITAL LETTER U WITH ACUTE */
    {    "U(", 0x016c },  /* Ŭ LATIN CAPITAL LETTER U WITH BREVE */
    {    "U*", 0x03a5 },  /* Υ GREEK CAPITAL LETTER UPSILON */
    {    "U-", 0x016a },  /* Ū LATIN CAPITAL LETTER U WITH MACRON */
    {  "U--:", 0x1e72 },  /* Ṳ LATIN CAPITAL LETTER U WITH DIAERESIS BELOW */
    {   "U-.", 0x1ee4 },  /* Ụ LATIN CAPITAL LETTER U WITH DOT BELOW */
    {   "U-:", 0x1e7a },  /* Ṻ LATIN CAPITAL LETTER U WITH MACRON AND DIAERESIS */
    {   "U->", 0x1e76 },  /* Ṷ LATIN CAPITAL LETTER U WITH CIRCUMFLEX BELOW */
    {   "U-?", 0x1e74 },  /* Ṵ LATIN CAPITAL LETTER U WITH TILDE BELOW */
    {   "U-o", 0x24ca },  /* Ⓤ CIRCLED LATIN CAPITAL LETTER U */
    {    "U0", 0x016e },  /* Ů LATIN CAPITAL LETTER U WITH RING ABOVE */
    {    "U2", 0x1ee6 },  /* Ủ LATIN CAPITAL LETTER U WITH HOOK ABOVE */
    {    "U5", 0x3045 },  /* ぅ HIRAGANA LETTER SMALL U */
    {    "U6", 0x30a6 },  /* ウ KATAKANA LETTER U */
    {    "U9", 0x01af },  /* Ư LATIN CAPITAL LETTER U WITH HORN */
    {   "U9!", 0x1eea },  /* Ừ LATIN CAPITAL LETTER U WITH HORN AND GRAVE */
    {   "U9'", 0x1ee8 },  /* Ứ LATIN CAPITAL LETTER U WITH HORN AND ACUTE */
    {  "U9-.", 0x1ef0 },  /* Ự LATIN CAPITAL LETTER U WITH HORN AND DOT BELOW */
    {   "U92", 0x1eec },  /* Ử LATIN CAPITAL LETTER U WITH HORN AND HOOK ABOVE */
    {   "U9?", 0x1eee },  /* Ữ LATIN CAPITAL LETTER U WITH HORN AND TILDE */
    {    "U:", 0x00dc },  /* Ü LATIN CAPITAL LETTER U WITH DIAERESIS */
    {   "U:!", 0x01db },  /* Ǜ LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE */
    {   "U:'", 0x01d7 },  /* Ǘ LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE */
    {   "U:-", 0x01d5 },  /* Ǖ LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON */
    {   "U:<", 0x01d9 },  /* Ǚ LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON */
    {    "U;", 0x0172 },  /* Ų LATIN CAPITAL LETTER U WITH OGONEK */
    {    "U<", 0x01d3 },  /* Ǔ LATIN CAPITAL LETTER U WITH CARON */
    {    "U=", 0x0423 },  /* У CYRILLIC CAPITAL LETTER U */
    {    "U>", 0x00db },  /* Û LATIN CAPITAL LETTER U WITH CIRCUMFLEX */
    {    "U?", 0x0168 },  /* Ũ LATIN CAPITAL LETTER U WITH TILDE */
    {   "U?'", 0x1e78 },  /* Ṹ LATIN CAPITAL LETTER U WITH TILDE AND ACUTE */
    {    "UA", 0xe002 },  /*  Unit space A (ISO-IR-8-1 064) */
    {    "UB", 0xe003 },  /*  Unit space B (ISO-IR-8-1 096) */
    {    "UD", 0x2195 },  /* ↕ UP DOWN ARROW */
    {    "UH", 0x253b },  /* ┻ BOX DRAWINGS HEAVY UP AND HORIZONTAL */
    {    "UL", 0x251b },  /* ┛ BOX DRAWINGS HEAVY UP AND LEFT */
    {   "ULr", 0x2539 },  /* ┹ BOX DRAWINGS RIGHT LIGHT AND LEFT UP HEAVY */
    {    "UR", 0x2517 },  /* ┗ BOX DRAWINGS HEAVY UP AND RIGHT */
    {    "US", 0x001f },  /*   UNIT SEPARATOR (IS1) */
    {    "UT", 0x25b2 },  /* ▲ BLACK UP-POINTING TRIANGLE */
    {   "UdH", 0x2547 },  /* ╇ BOX DRAWINGS DOWN LIGHT AND UP HORIZONTAL HEAVY */
    {   "UdL", 0x2529 },  /* ┩ BOX DRAWINGS DOWN LIGHT AND LEFT UP HEAVY */
    {  "UdLr", 0x2543 },  /* ╃ BOX DRAWINGS LEFT UP HEAVY AND RIGHT DOWN LIGHT */
    {   "UdR", 0x2521 },  /* ┡ BOX DRAWINGS DOWN LIGHT AND RIGHT UP HEAVY */
    {   "Udh", 0x2540 },  /* ╀ BOX DRAWINGS UP HEAVY AND DOWN HORIZONTAL LIGHT */
    {   "Udl", 0x2526 },  /* ┦ BOX DRAWINGS UP HEAVY AND LEFT DOWN LIGHT */
    {  "UdlR", 0x2544 },  /* ╄ BOX DRAWINGS RIGHT UP HEAVY AND LEFT DOWN LIGHT */
    {   "Udr", 0x251e },  /* ┞ BOX DRAWINGS UP HEAVY AND RIGHT DOWN LIGHT */
    {    "Uh", 0x2538 },  /* ┸ BOX DRAWINGS UP HEAVY AND HORIZONTAL LIGHT */
    {    "Ul", 0x251a },  /* ┚ BOX DRAWINGS UP HEAVY AND LEFT LIGHT */
    {   "UlR", 0x253a },  /* ┺ BOX DRAWINGS LEFT LIGHT AND RIGHT UP HEAVY */
    {    "Ur", 0x2516 },  /* ┖ BOX DRAWINGS UP HEAVY AND RIGHT LIGHT */
    {    "V%", 0x040e },  /* Ў CYRILLIC CAPITAL LETTER SHORT U (Byelorussian) */
    {    "V*", 0x03ab },  /* Ϋ GREEK CAPITAL LETTER UPSILON WITH DIAERESIS */
    {   "V-.", 0x1e7e },  /* Ṿ LATIN CAPITAL LETTER V WITH DOT BELOW */
    {   "V-o", 0x24cb },  /* Ⓥ CIRCLED LATIN CAPITAL LETTER V */
    {    "V3", 0x0474 },  /* Ѵ CYRILLIC CAPITAL LETTER IZHITSA */
    {    "V=", 0x0412 },  /* В CYRILLIC CAPITAL LETTER VE */
    {    "V?", 0x1e7c },  /* Ṽ LATIN CAPITAL LETTER V WITH TILDE */
    {    "VH", 0x254b },  /* ╋ BOX DRAWINGS HEAVY VERTICAL AND HORIZONTAL */
    {    "VL", 0x252b },  /* ┫ BOX DRAWINGS HEAVY VERTICAL AND LEFT */
    {   "VLr", 0x2549 },  /* ╉ BOX DRAWINGS RIGHT LIGHT AND LEFT VERTICAL HEAVY */
    {    "VR", 0x2523 },  /* ┣ BOX DRAWINGS HEAVY VERTICAL AND RIGHT */
    {    "VS", 0x008a },  /*   LINE TABULATION SET (VTS) */
    {    "VT", 0x000b },  /*   LINE TABULATION (VT) */
    {    "VV", 0x2503 },  /* ┃ BOX DRAWINGS HEAVY VERTICAL */
    {    "Va", 0x30f7 },  /* ヷ KATAKANA LETTER VA */
    {    "Ve", 0x30f9 },  /* ヹ KATAKANA LETTER VE */
    {    "Vh", 0x2542 },  /* ╂ BOX DRAWINGS VERTICAL HEAVY AND HORIZONTAL LIGHT */
    {    "Vi", 0x30f8 },  /* ヸ KATAKANA LETTER VI */
    {    "Vl", 0x2528 },  /* ┨ BOX DRAWINGS VERTICAL HEAVY AND LEFT LIGHT */
    {   "VlR", 0x254a },  /* ╊ BOX DRAWINGS LEFT LIGHT AND RIGHT VERTICAL HEAVY */
    {    "Vo", 0x30fa },  /* ヺ KATAKANA LETTER VO */
    {    "Vr", 0x2520 },  /* ┠ BOX DRAWINGS VERTICAL HEAVY AND RIGHT LIGHT */
    {    "Vs", 0x2423 },  /* ␣ OPEN BOX */
    {    "Vu", 0x30f4 },  /* ヴ KATAKANA LETTER VU */
    {    "W!", 0x1e80 },  /* Ẁ LATIN CAPITAL LETTER W WITH GRAVE */
    {    "W%", 0x038f },  /* Ώ GREEK CAPITAL LETTER OMEGA WITH ACUTE */
    {    "W'", 0x1e82 },  /* Ẃ LATIN CAPITAL LETTER W WITH ACUTE */
    {    "W*", 0x03a9 },  /* Ω GREEK CAPITAL LETTER OMEGA */
    {    "W+", 0x05d5 },  /* ו HEBREW LETTER VAV */
    {   "W-.", 0x1e88 },  /* Ẉ LATIN CAPITAL LETTER W WITH DOT BELOW */
    {   "W-o", 0x24cc },  /* Ⓦ CIRCLED LATIN CAPITAL LETTER W */
    {    "W.", 0x1e86 },  /* Ẇ LATIN CAPITAL LETTER W WITH DOT ABOVE */
    {    "W:", 0x1e84 },  /* Ẅ LATIN CAPITAL LETTER W WITH DIAERESIS */
    {    "W=", 0x20a9 },  /* ₩ WON SIGN */
    {    "W>", 0x0174 },  /* Ŵ LATIN CAPITAL LETTER W WITH CIRCUMFLEX */
    {    "WA", 0x30ee },  /* ヮ KATAKANA LETTER SMALL WA */
    {    "Wa", 0x30ef },  /* ワ KATAKANA LETTER WA */
    {    "We", 0x30f1 },  /* ヱ KATAKANA LETTER WE */
    {    "Wi", 0x30f0 },  /* ヰ KATAKANA LETTER WI */
    {    "Wo", 0x30f2 },  /* ヲ KATAKANA LETTER WO */
    {    "X*", 0x03a7 },  /* Χ GREEK CAPITAL LETTER CHI */
    {    "X+", 0x05d7 },  /* ח HEBREW LETTER HET */
    {   "X-o", 0x24cd },  /* Ⓧ CIRCLED LATIN CAPITAL LETTER X */
    {    "X.", 0x1e8a },  /* Ẋ LATIN CAPITAL LETTER X WITH DOT ABOVE */
    {    "X:", 0x1e8c },  /* Ẍ LATIN CAPITAL LETTER X WITH DIAERESIS */
    {    "XX", 0x2717 },  /* ✗ BALLOT X */
    {    "Y!", 0x1ef2 },  /* Ỳ LATIN CAPITAL LETTER Y WITH GRAVE */
    {    "Y%", 0x0389 },  /* Ή GREEK CAPITAL LETTER ETA WITH ACUTE */
    {    "Y'", 0x00dd },  /* Ý LATIN CAPITAL LETTER Y WITH ACUTE */
    {    "Y*", 0x0397 },  /* Η GREEK CAPITAL LETTER ETA */
    {   "Y-.", 0x1ef4 },  /* Ỵ LATIN CAPITAL LETTER Y WITH DOT BELOW */
    {   "Y-o", 0x24ce },  /* Ⓨ CIRCLED LATIN CAPITAL LETTER Y */
    {    "Y.", 0x1e8e },  /* Ẏ LATIN CAPITAL LETTER Y WITH DOT ABOVE */
    {    "Y2", 0x1ef6 },  /* Ỷ LATIN CAPITAL LETTER Y WITH HOOK ABOVE */
    {    "Y3", 0x0462 },  /* Ѣ CYRILLIC CAPITAL LETTER YAT */
    {    "Y:", 0x0178 },  /* Ÿ LATIN CAPITAL LETTER Y WITH DIAERESIS */
    {    "Y=", 0x042b },  /* Ы CYRILLIC CAPITAL LETTER YERU */
    {    "Y>", 0x0176 },  /* Ŷ LATIN CAPITAL LETTER Y WITH CIRCUMFLEX */
    {    "Y?", 0x1ef8 },  /* Ỹ LATIN CAPITAL LETTER Y WITH TILDE */
    {    "YA", 0x30e3 },  /* ャ KATAKANA LETTER SMALL YA */
    {    "YI", 0x0407 },  /* Ї CYRILLIC CAPITAL LETTER YI (Ukrainian) */
    {    "YO", 0x30e7 },  /* ョ KATAKANA LETTER SMALL YO */
    {    "YU", 0x30e5 },  /* ュ KATAKANA LETTER SMALL YU */
    {    "Ya", 0x30e4 },  /* ヤ KATAKANA LETTER YA */
    {    "Ye", 0x00a5 },  /* ¥ YEN SIGN */
    {    "Yo", 0x30e8 },  /* ヨ KATAKANA LETTER YO */
    {    "Yu", 0x30e6 },  /* ユ KATAKANA LETTER YU */
    {    "Z%", 0x0416 },  /* Ж CYRILLIC CAPITAL LETTER ZHE */
    {    "Z'", 0x0179 },  /* Ź LATIN CAPITAL LETTER Z WITH ACUTE */
    {    "Z*", 0x0396 },  /* Ζ GREEK CAPITAL LETTER ZETA */
    {    "Z+", 0x05d6 },  /* ז HEBREW LETTER ZAYIN */
    {   "Z-.", 0x1e92 },  /* Ẓ LATIN CAPITAL LETTER Z WITH DOT BELOW */
    {   "Z-o", 0x24cf },  /* Ⓩ CIRCLED LATIN CAPITAL LETTER Z */
    {    "Z.", 0x017b },  /* Ż LATIN CAPITAL LETTER Z WITH DOT ABOVE */
    {    "Z/", 0x01b5 },  /* Ƶ LATIN CAPITAL LETTER Z WITH STROKE */
    {    "Z<", 0x017d },  /* Ž LATIN CAPITAL LETTER Z WITH CARON */
    {    "Z=", 0x0417 },  /* З CYRILLIC CAPITAL LETTER ZE */
    {    "Z>", 0x1e90 },  /* Ẑ LATIN CAPITAL LETTER Z WITH CIRCUMFLEX */
    {    "ZJ", 0x05e6 },  /* צ HEBREW LETTER TSADI */
    {    "Z_", 0x1e94 },  /* Ẕ LATIN CAPITAL LETTER Z WITH LINE BELOW */
    {    "Za", 0x30b6 },  /* ザ KATAKANA LETTER ZA */
    {    "Ze", 0x30bc },  /* ゼ KATAKANA LETTER ZE */
    {    "Zi", 0x30b8 },  /* ジ KATAKANA LETTER ZI */
    {    "Zj", 0x05e5 },  /* ץ HEBREW LETTER FINAL TSADI */
    {    "Zo", 0x30be },  /* ゾ KATAKANA LETTER ZO */
    {    "Zu", 0x30ba },  /* ズ KATAKANA LETTER ZU */
    {    "a!", 0x00e0 },  /* à LATIN SMALL LETTER A WITH GRAVE */
    {    "a%", 0x03ac },  /* ά GREEK SMALL LETTER ALPHA WITH ACUTE */
    {    "a'", 0x00e1 },  /* á LATIN SMALL LETTER A WITH ACUTE */
    {    "a(", 0x0103 },  /* ă LATIN SMALL LETTER A WITH BREVE */
    {   "a(!", 0x1eb1 },  /* ằ LATIN SMALL LETTER A WITH BREVE AND GRAVE */
    {   "a('", 0x1eaf },  /* ắ LATIN SMALL LETTER A WITH BREVE AND ACUTE */
    {  "a(-.", 0x1eb7 },  /* ặ LATIN SMALL LETTER A WITH BREVE AND DOT BELOW */
    {   "a(2", 0x1eb3 },  /* ẳ LATIN SMALL LETTER A WITH BREVE AND HOOK ABOVE */
    {   "a(?", 0x1eb5 },  /* ẵ LATIN SMALL LETTER A WITH BREVE AND TILDE */
    {    "a*", 0x03b1 },  /* α GREEK SMALL LETTER ALPHA */
    {    "a+", 0x0627 },  /* ا ARABIC LETTER ALEF */
    {   "a+-", 0xfe8d },  /* ﺍ ARABIC LETTER ALEF ISOLATED FORM */
    {   "a+.", 0xfe8e },  /* ﺎ ARABIC LETTER ALEF FINAL FORM */
    {   "a+:", 0xe022 },  /*  ARABIC LETTER ALEF FINAL FORM COMPATIBILITY (IBM868 144) */
    {    "a-", 0x0101 },  /* ā LATIN SMALL LETTER A WITH MACRON */
    {   "a-.", 0x1ea1 },  /* ạ LATIN SMALL LETTER A WITH DOT BELOW */
    {   "a-0", 0x1e01 },  /* ḁ LATIN SMALL LETTER A WITH RING BELOW */
    {   "a-o", 0x24d0 },  /* ⓐ CIRCLED LATIN SMALL LETTER A */
    {    "a1", 0x01df },  /* ǟ LATIN SMALL LETTER A WITH DIAERESIS AND MACRON */
    {    "a2", 0x1ea3 },  /* ả LATIN SMALL LETTER A WITH HOOK ABOVE */
    {    "a3", 0x01e3 },  /* ǣ LATIN SMALL LETTER AE WITH MACRON */
    {    "a4", 0x311a },  /* ㄚ BOPOMOFO LETTER A */
    {    "a5", 0x3042 },  /* あ HIRAGANA LETTER A */
    {    "a6", 0x30a1 },  /* ァ KATAKANA LETTER SMALL A */
    {    "a7", 0x01e1 },  /* ǡ LATIN SMALL LETTER A WITH DOT ABOVE AND MACRON */
    {    "a:", 0x00e4 },  /* ä LATIN SMALL LETTER A WITH DIAERESIS */
    {    "a;", 0x0105 },  /* ą LATIN SMALL LETTER A WITH OGONEK */
    {    "a<", 0x01ce },  /* ǎ LATIN SMALL LETTER A WITH CARON */
    {    "a=", 0x0430 },  /* а CYRILLIC SMALL LETTER A */
    {    "a>", 0x00e2 },  /* â LATIN SMALL LETTER A WITH CIRCUMFLEX */
    {   "a>!", 0x1ea7 },  /* ầ LATIN SMALL LETTER A WITH CIRCUMFLEX AND GRAVE */
    {   "a>'", 0x1ea5 },  /* ấ LATIN SMALL LETTER A WITH CIRCUMFLEX AND ACUTE */
    {  "a>-.", 0x1ead },  /* ậ LATIN SMALL LETTER A WITH CIRCUMFLEX AND DOT BELOW */
    {   "a>2", 0x1ea9 },  /* ẩ LATIN SMALL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE */
    {   "a>?", 0x1eab },  /* ẫ LATIN SMALL LETTER A WITH CIRCUMFLEX AND TILDE */
    {    "a?", 0x00e3 },  /* ã LATIN SMALL LETTER A WITH TILDE */
    {    "aH", 0x0623 },  /* أ ARABIC LETTER ALEF WITH HAMZA ABOVE */
    {   "aH.", 0xfe84 },  /* ﺄ ARABIC LETTER ALEF WITH HAMZA ABOVE FINAL FORM */
    {    "aM", 0x0622 },  /* آ ARABIC LETTER ALEF WITH MADDA ABOVE */
    {   "aM.", 0xfe82 },  /* ﺂ ARABIC LETTER ALEF WITH MADDA ABOVE FINAL FORM */
    {    "aN", 0x3124 },  /* ㄤ BOPOMOFO LETTER ANG */
    {    "aR", 0x2169 },  /* Ⅹ ROMAN NUMERAL TEN */
    {    "aS", 0x0670 },  /* ٰ SUPERSCRIPT ARABIC LETTER ALEF */
    {    "aa", 0x00e5 },  /* å LATIN SMALL LETTER A WITH RING ABOVE */
    {   "aa'", 0x01fb },  /* ǻ LATIN SMALL LETTER A WITH RING ABOVE AND ACUTE */
    {    "ae", 0x00e6 },  /* æ LATIN SMALL LETTER AE */
    {   "ae'", 0x01fd },  /* ǽ LATIN SMALL LETTER AE WITH ACUTE */
    {    "ah", 0x0625 },  /* إ ARABIC LETTER ALEF WITH HAMZA BELOW */
    {    "ai", 0x311e },  /* ㄞ BOPOMOFO LETTER AI */
    {    "am", 0xe01f },  /*  ANTE MERIDIAM SIGN (ISO-IR-149 0267) */
    {    "an", 0x3122 },  /* ㄢ BOPOMOFO LETTER AN */
    {    "ar", 0x2179 },  /* ⅹ SMALL ROMAN NUMERAL TEN */
    {    "au", 0x3120 },  /* ㄠ BOPOMOFO LETTER AU */
    {    "b*", 0x03b2 },  /* β GREEK SMALL LETTER BETA */
    {    "b+", 0x0628 },  /* ب ARABIC LETTER BEH */
    {   "b+,", 0xfe90 },  /* ﺐ ARABIC LETTER BEH INITIAL FORM */
    {   "b+-", 0xfe8f },  /* ﺏ ARABIC LETTER BEH ISOLATED FORM */
    {   "b+.", 0xfe92 },  /* ﺒ ARABIC LETTER BEH FINAL FORM */
    {   "b+;", 0xfe91 },  /* ﺑ ARABIC LETTER BEH MEDIAL FORM */
    {   "b-.", 0x1e05 },  /* ḅ LATIN SMALL LETTER B WITH DOT BELOW */
    {   "b-o", 0x24d1 },  /* ⓑ CIRCLED LATIN SMALL LETTER B */
    {    "b.", 0x1e03 },  /* ḃ LATIN SMALL LETTER B WITH DOT ABOVE */
    {    "b3", 0xe01b },  /*  GREEK SMALL LETTER MIDDLE BETA (ISO-IR-18 99) */
    {    "b4", 0x3105 },  /* ㄅ BOPOMOFO LETTER B */
    {    "b=", 0x0431 },  /* б CYRILLIC SMALL LETTER BE */
    {    "bR", 0x216a },  /* Ⅺ ROMAN NUMERAL ELEVEN */
    {    "b_", 0x1e07 },  /* ḇ LATIN SMALL LETTER B WITH LINE BELOW */
    {    "ba", 0x3070 },  /* ば HIRAGANA LETTER BA */
    {    "be", 0x3079 },  /* べ HIRAGANA LETTER BE */
    {    "bi", 0x3073 },  /* び HIRAGANA LETTER BI */
    {    "bo", 0x307c },  /* ぼ HIRAGANA LETTER BO */
    {    "br", 0x217a },  /* ⅺ SMALL ROMAN NUMERAL ELEVEN */
    {    "bu", 0x3076 },  /* ぶ HIRAGANA LETTER BU */
    {    "c%", 0x0447 },  /* ч CYRILLIC SMALL LETTER CHE */
    {    "c'", 0x0107 },  /* ć LATIN SMALL LETTER C WITH ACUTE */
    {    "c*", 0x03be },  /* ξ GREEK SMALL LETTER XI */
    {    "c+", 0x0635 },  /* ص ARABIC LETTER SAD */
    {   "c+,", 0xfeba },  /* ﺺ ARABIC LETTER SAD INITIAL FORM */
    {   "c+-", 0xfeb9 },  /* ﺹ ARABIC LETTER SAD ISOLATED FORM */
    {   "c+.", 0xfebc },  /* ﺼ ARABIC LETTER SAD FINAL FORM */
    {   "c+;", 0xfebb },  /* ﺻ ARABIC LETTER SAD MEDIAL FORM */
    {    "c,", 0x00e7 },  /* ç LATIN SMALL LETTER C WITH CEDILLA */
    {   "c,'", 0x1e09 },  /* ḉ LATIN SMALL LETTER C WITH CEDILLA AND ACUTE */
    {   "c-o", 0x24d2 },  /* ⓒ CIRCLED LATIN SMALL LETTER C */
    {    "c.", 0x010b },  /* ċ LATIN SMALL LETTER C WITH DOT ABOVE */
    {    "c3", 0x0481 },  /* ҁ CYRILLIC SMALL LETTER KOPPA */
    {    "c4", 0x3118 },  /* ㄘ BOPOMOFO LETTER C */
    {    "c<", 0x010d },  /* č LATIN SMALL LETTER C WITH CARON */
    {    "c=", 0x0446 },  /* ц CYRILLIC SMALL LETTER TSE */
    {    "c>", 0x0109 },  /* ĉ LATIN SMALL LETTER C WITH CIRCUMFLEX */
    {    "cC", 0x2663 },  /* ♣ BLACK CLUB SUIT */
    {   "cC-", 0x2667 },  /* ♧ WHITE CLUB SUIT */
    {    "cD", 0x2662 },  /* ♢ WHITE DIAMOND SUIT */
    {   "cD-", 0x2666 },  /* ♦ BLACK DIAMOND SUIT */
    {    "cH", 0x2661 },  /* ♡ WHITE HEART SUIT */
    {   "cH-", 0x2665 },  /* ♥ BLACK HEART SUIT */
    {    "cR", 0x216b },  /* Ⅻ ROMAN NUMERAL TWELVE */
    {    "cS", 0x2660 },  /* ♠ BLACK SPADE SUIT */
    {   "cS-", 0x2664 },  /* ♤ WHITE SPADE SUIT */
    {    "ch", 0x3114 },  /* ㄔ BOPOMOFO LETTER CH */
    {    "co", 0x2105 },  /* ℅ CARE OF */
    {    "cr", 0x217b },  /* ⅻ SMALL ROMAN NUMERAL TWELVE */
    {    "d%", 0x0452 },  /* ђ CYRILLIC SMALL LETTER DJE (Serbocroatian) */
    {    "d*", 0x03b4 },  /* δ GREEK SMALL LETTER DELTA */
    {    "d+", 0x062f },  /* د ARABIC LETTER DAL */
    {   "d+-", 0xfea9 },  /* ﺩ ARABIC LETTER DAL ISOLATED FORM */
    {   "d+.", 0xfeaa },  /* ﺪ ARABIC LETTER DAL FINAL FORM */
    {    "d,", 0x1e11 },  /* ḑ LATIN SMALL LETTER D WITH CEDILLA */
    {    "d-", 0x00f0 },  /* ð LATIN SMALL LETTER ETH (Icelandic) */
    {   "d-.", 0x1e0d },  /* ḍ LATIN SMALL LETTER D WITH DOT BELOW */
    {   "d->", 0x1e13 },  /* ḓ LATIN SMALL LETTER D WITH CIRCUMFLEX BELOW */
    {   "d-o", 0x24d3 },  /* ⓓ CIRCLED LATIN SMALL LETTER D */
    {    "d.", 0x1e0b },  /* ḋ LATIN SMALL LETTER D WITH DOT ABOVE */
    {    "d/", 0x0111 },  /* đ LATIN SMALL LETTER D WITH STROKE */
    {    "d4", 0x3109 },  /* ㄉ BOPOMOFO LETTER D */
    {    "d<", 0x010f },  /* ď LATIN SMALL LETTER D WITH CARON */
    {    "d=", 0x0434 },  /* д CYRILLIC SMALL LETTER DE */
    {    "dH", 0x252f },  /* ┯ BOX DRAWINGS DOWN LIGHT AND HORIZONTAL HEAVY */
    {    "dL", 0x2511 },  /* ┑ BOX DRAWINGS DOWN LIGHT AND LEFT HEAVY */
    {   "dLr", 0x252d },  /* ┭ BOX DRAWINGS LEFT HEAVY AND RIGHT DOWN LIGHT */
    {    "dP", 0x2202 },  /* ∂ PARTIAL DIFFERENTIAL */
    {    "dR", 0x250d },  /* ┍ BOX DRAWINGS DOWN LIGHT AND RIGHT HEAVY */
    {    "dT", 0x25bd },  /* ▽ WHITE DOWN-POINTING TRIANGLE */
    {    "d_", 0x1e0f },  /* ḏ LATIN SMALL LETTER D WITH LINE BELOW */
    {    "da", 0x3060 },  /* だ HIRAGANA LETTER DA */
    {    "dd", 0x0636 },  /* ض ARABIC LETTER DAD */
    {   "dd,", 0xfebe },  /* ﺾ ARABIC LETTER DAD INITIAL FORM */
    {   "dd-", 0xfebd },  /* ﺽ ARABIC LETTER DAD ISOLATED FORM */
    {   "dd.", 0xfec0 },  /* ﻀ ARABIC LETTER DAD FINAL FORM */
    {   "dd;", 0xfebf },  /* ﺿ ARABIC LETTER DAD MEDIAL FORM */
    {    "de", 0x3067 },  /* で HIRAGANA LETTER DE */
    {    "dh", 0x252c },  /* ┬ BOX DRAWINGS LIGHT DOWN AND HORIZONTAL */
    {    "di", 0x3062 },  /* ぢ HIRAGANA LETTER DI */
    {    "dk", 0x0630 },  /* ذ ARABIC LETTER THAL */
    {   "dk-", 0xfeab },  /* ﺫ ARABIC LETTER THAL ISOLATED FORM */
    {   "dk.", 0xfeac },  /* ﺬ ARABIC LETTER THAL FINAL FORM */
    {    "dl", 0x2510 },  /* ┐ BOX DRAWINGS LIGHT DOWN AND LEFT */
    {   "dlR", 0x252e },  /* ┮ BOX DRAWINGS RIGHT HEAVY AND LEFT DOWN LIGHT */
    {    "do", 0x3069 },  /* ど HIRAGANA LETTER DO */
    {    "dr", 0x250c },  /* ┌ BOX DRAWINGS LIGHT DOWN AND RIGHT */
    {    "ds", 0x0455 },  /* ѕ CYRILLIC SMALL LETTER DZE (Macedonian) */
    {    "du", 0x3065 },  /* づ HIRAGANA LETTER DU */
    {    "dz", 0x045f },  /* џ CYRILLIC SMALL LETTER DZHE */
    {    "e!", 0x00e8 },  /* è LATIN SMALL LETTER E WITH GRAVE */
    {    "e%", 0x03ad },  /* έ GREEK SMALL LETTER EPSILON WITH ACUTE */
    {    "e'", 0x00e9 },  /* é LATIN SMALL LETTER E WITH ACUTE */
    {    "e(", 0x0115 },  /* ĕ LATIN SMALL LETTER E WITH BREVE */
    {    "e*", 0x03b5 },  /* ε GREEK SMALL LETTER EPSILON */
    {    "e+", 0x0639 },  /* ع ARABIC LETTER AIN */
    {   "e+,", 0xfeca },  /* ﻊ ARABIC LETTER AIN INITIAL FORM */
    {   "e+-", 0xfec9 },  /* ﻉ ARABIC LETTER AIN ISOLATED FORM */
    {   "e+.", 0xfecc },  /* ﻌ ARABIC LETTER AIN FINAL FORM */
    {   "e+;", 0xfecb },  /* ﻋ ARABIC LETTER AIN MEDIAL FORM */
    {   "e,(", 0x1e1d },  /* ḝ LATIN SMALL LETTER E WITH CEDILLA AND BREVE */
    {    "e-", 0x0113 },  /* ē LATIN SMALL LETTER E WITH MACRON */
    {   "e-!", 0x1e15 },  /* ḕ LATIN SMALL LETTER E WITH MACRON AND GRAVE */
    {   "e-'", 0x1e17 },  /* ḗ LATIN SMALL LETTER E WITH MACRON AND ACUTE */
    {   "e-.", 0x1eb9 },  /* ẹ LATIN SMALL LETTER E WITH DOT BELOW */
    {   "e->", 0x1e19 },  /* ḙ LATIN SMALL LETTER E WITH CIRCUMFLEX BELOW */
    {   "e-?", 0x1e1b },  /* ḛ LATIN SMALL LETTER E WITH TILDE BELOW */
    {   "e-o", 0x24d4 },  /* ⓔ CIRCLED LATIN SMALL LETTER E */
    {    "e.", 0x0117 },  /* ė LATIN SMALL LETTER E WITH DOT ABOVE */
    {    "e2", 0x1ebb },  /* ẻ LATIN SMALL LETTER E WITH HOOK ABOVE */
    {    "e4", 0x311c },  /* ㄜ BOPOMOFO LETTER E */
    {    "e5", 0x3048 },  /* え HIRAGANA LETTER E */
    {    "e6", 0x30a7 },  /* ェ KATAKANA LETTER SMALL E */
    {    "e:", 0x00eb },  /* ë LATIN SMALL LETTER E WITH DIAERESIS */
    {    "e;", 0x0119 },  /* ę LATIN SMALL LETTER E WITH OGONEK */
    {    "e<", 0x011b },  /* ě LATIN SMALL LETTER E WITH CARON */
    {    "e=", 0x0435 },  /* е CYRILLIC SMALL LETTER IE */
    {    "e>", 0x00ea },  /* ê LATIN SMALL LETTER E WITH CIRCUMFLEX */
    {   "e>!", 0x1ec1 },  /* ề LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE */
    {   "e>'", 0x1ebf },  /* ế LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE */
    {  "e>-.", 0x1ec7 },  /* ệ LATIN SMALL LETTER E WITH CIRCUMFLEX AND DOT BELOW */
    {   "e>2", 0x1ec3 },  /* ể LATIN SMALL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE */
    {   "e>?", 0x1ec5 },  /* ễ LATIN SMALL LETTER E WITH CIRCUMFLEX AND TILDE */
    {    "e?", 0x1ebd },  /* ẽ LATIN SMALL LETTER E WITH TILDE */
    {    "eN", 0x3125 },  /* ㄥ BOPOMOFO LETTER ENG */
    {    "ed", 0xe01e },  /*  LATIN SMALL LETTER EZH (ISO-IR-158 142) */
    {   "eh4", 0x311d },  /* ㄝ BOPOMOFO LETTER EH */
    {    "ei", 0x311f },  /* ㄟ BOPOMOFO LETTER EI */
    {    "en", 0x3123 },  /* ㄣ BOPOMOFO LETTER EN */
    {    "er", 0x3126 },  /* ㄦ BOPOMOFO LETTER ER */
    {    "ez", 0x01ef },  /* ǯ LATIN SMALL LETTER EZH WITH CARON */
    {    "f(", 0xe01d },  /*  FUNCTION SIGN (ISO-IR-143 221) */
    {    "f*", 0x03c6 },  /* φ GREEK SMALL LETTER PHI */
    {    "f+", 0x0641 },  /* ف ARABIC LETTER FEH */
    {   "f+,", 0xfed2 },  /* ﻒ ARABIC LETTER FEH INITIAL FORM */
    {   "f+-", 0xfed1 },  /* ﻑ ARABIC LETTER FEH ISOLATED FORM */
    {   "f+.", 0xfed4 },  /* ﻔ ARABIC LETTER FEH FINAL FORM */
    {   "f+;", 0xfed3 },  /* ﻓ ARABIC LETTER FEH MEDIAL FORM */
    {   "f-o", 0x24d5 },  /* ⓕ CIRCLED LATIN SMALL LETTER F */
    {    "f.", 0x1e1f },  /* ḟ LATIN SMALL LETTER F WITH DOT ABOVE */
    {    "f3", 0x0473 },  /* ѳ CYRILLIC SMALL LETTER FITA */
    {    "f4", 0x3108 },  /* ㄈ BOPOMOFO LETTER F */
    {    "f=", 0x0444 },  /* ф CYRILLIC SMALL LETTER EF */
    {    "fS", 0x25a0 },  /* ■ BLACK SQUARE */
    {    "ff", 0xfb00 },  /* ﬀ LATIN SMALL LIGATURE FF */
    {   "ffi", 0xfb03 },  /* ﬃ LATIN SMALL LIGATURE FFI */
    {   "ffl", 0xfb04 },  /* ﬄ LATIN SMALL LIGATURE FFL */
    {    "fi", 0xfb01 },  /* ﬁ LATIN SMALL LIGATURE FI */
    {    "fl", 0xfb02 },  /* ﬂ LATIN SMALL LIGATURE FL */
    {    "ft", 0xfb05 },  /* ﬅ LATIN SMALL LIGATURE FT */
    {    "g%", 0x0453 },  /* ѓ CYRILLIC SMALL LETTER GJE (Macedonian) */
    {    "g'", 0x01f5 },  /* ǵ LATIN SMALL LETTER G WITH ACUTE */
    {    "g(", 0x011f },  /* ğ LATIN SMALL LETTER G WITH BREVE */
    {    "g*", 0x03b3 },  /* γ GREEK SMALL LETTER GAMMA */
    {    "g+", 0x062c },  /* ج ARABIC LETTER JEEM */
    {   "g+,", 0xfe9e },  /* ﺞ ARABIC LETTER JEEM INITIAL FORM */
    {   "g+-", 0xfe9d },  /* ﺝ ARABIC LETTER JEEM ISOLATED FORM */
    {   "g+.", 0xfea0 },  /* ﺠ ARABIC LETTER JEEM FINAL FORM */
    {   "g+;", 0xfe9f },  /* ﺟ ARABIC LETTER JEEM MEDIAL FORM */
    {    "g,", 0x0123 },  /* ģ LATIN SMALL LETTER G WITH CEDILLA */
    {    "g-", 0x1e21 },  /* ḡ LATIN SMALL LETTER G WITH MACRON */
    {   "g-o", 0x24d6 },  /* ⓖ CIRCLED LATIN SMALL LETTER G */
    {    "g.", 0x0121 },  /* ġ LATIN SMALL LETTER G WITH DOT ABOVE */
    {    "g/", 0x01e5 },  /* ǥ LATIN SMALL LETTER G WITH STROKE */
    {    "g3", 0x0491 },  /* ґ CYRILLIC SMALL LETTER GHE WITH UPTURN */
    {    "g4", 0x310d },  /* ㄍ BOPOMOFO LETTER G */
    {    "g<", 0x01e7 },  /* ǧ LATIN SMALL LETTER G WITH CARON */
    {    "g=", 0x0433 },  /* г CYRILLIC SMALL LETTER GHE */
    {    "g>", 0x011d },  /* ĝ LATIN SMALL LETTER G WITH CIRCUMFLEX */
    {    "ga", 0x304c },  /* が HIRAGANA LETTER GA */
    {    "ge", 0x3052 },  /* げ HIRAGANA LETTER GE */
    {    "gf", 0x06af },  /* گ ARABIC LETTER GAF */
    {    "gi", 0x304e },  /* ぎ HIRAGANA LETTER GI */
    {    "gn", 0x312c },  /* ㄬ BOPOMOFO LETTER GN */
    {    "go", 0x3054 },  /* ご HIRAGANA LETTER GO */
    {    "gu", 0x3050 },  /* ぐ HIRAGANA LETTER GU */
    {    "h*", 0x03b8 },  /* θ GREEK SMALL LETTER THETA */
    {    "h+", 0x0647 },  /* ه ARABIC LETTER HEH */
    {   "h+,", 0xfeea },  /* ﻪ ARABIC LETTER HEH INITIAL FORM */
    {   "h+-", 0xfee9 },  /* ﻩ ARABIC LETTER HEH ISOLATED FORM */
    {   "h+.", 0xfeec },  /* ﻬ ARABIC LETTER HEH FINAL FORM */
    {   "h+;", 0xfeeb },  /* ﻫ ARABIC LETTER HEH MEDIAL FORM */
    {    "h,", 0x1e29 },  /* ḩ LATIN SMALL LETTER H WITH CEDILLA */
    {   "h-(", 0x1e2b },  /* ḫ LATIN SMALL LETTER H WITH BREVE BELOW */
    {   "h-.", 0x1e25 },  /* ḥ LATIN SMALL LETTER H WITH DOT BELOW */
    {   "h-o", 0x24d7 },  /* ⓗ CIRCLED LATIN SMALL LETTER H */
    {    "h.", 0x1e23 },  /* ḣ LATIN SMALL LETTER H WITH DOT ABOVE */
    {    "h/", 0x0127 },  /* ħ LATIN SMALL LETTER H WITH STROKE */
    {    "h4", 0x310f },  /* ㄏ BOPOMOFO LETTER H */
    {    "h:", 0x1e27 },  /* ḧ LATIN SMALL LETTER H WITH DIAERESIS */
    {    "h=", 0x0445 },  /* х CYRILLIC SMALL LETTER HA */
    {    "h>", 0x0125 },  /* ĥ LATIN SMALL LETTER H WITH CIRCUMFLEX */
    {    "h_", 0x1e96 },  /* ẖ LATIN SMALL LETTER H WITH LINE BELOW */
    {    "ha", 0x306f },  /* は HIRAGANA LETTER HA */
    {    "he", 0x3078 },  /* へ HIRAGANA LETTER HE */
    {    "hh", 0x2500 },  /* ─ BOX DRAWINGS LIGHT HORIZONTAL */
    {    "hi", 0x3072 },  /* ひ HIRAGANA LETTER HI */
    {    "hk", 0x062d },  /* ح ARABIC LETTER HAH */
    {   "hk,", 0xfea2 },  /* ﺢ ARABIC LETTER HAH INITIAL FORM */
    {   "hk-", 0xfea1 },  /* ﺡ ARABIC LETTER HAH ISOLATED FORM */
    {   "hk.", 0xfea4 },  /* ﺤ ARABIC LETTER HAH FINAL FORM */
    {   "hk;", 0xfea3 },  /* ﺣ ARABIC LETTER HAH MEDIAL FORM */
    {    "ho", 0x307b },  /* ほ HIRAGANA LETTER HO */
    {    "hu", 0x3075 },  /* ふ HIRAGANA LETTER HU */
    {    "i!", 0x00ec },  /* ì LATIN SMALL LETTER I WITH GRAVE */
    {    "i%", 0x03af },  /* ί GREEK SMALL LETTER IOTA WITH ACUTE */
    {    "i'", 0x00ed },  /* í LATIN SMALL LETTER I WITH ACUTE */
    {    "i(", 0x012d },  /* ĭ LATIN SMALL LETTER I WITH BREVE */
    {    "i*", 0x03b9 },  /* ι GREEK SMALL LETTER IOTA */
    {    "i+", 0x063a },  /* غ ARABIC LETTER GHAIN */
    {   "i+,", 0xfece },  /* ﻎ ARABIC LETTER GHAIN INITIAL FORM */
    {   "i+-", 0xfecd },  /* ﻍ ARABIC LETTER GHAIN ISOLATED FORM */
    {   "i+.", 0xfed0 },  /* ﻐ ARABIC LETTER GHAIN FINAL FORM */
    {   "i+;", 0xfecf },  /* ﻏ ARABIC LETTER GHAIN MEDIAL FORM */
    {    "i-", 0x012b },  /* ī LATIN SMALL LETTER I WITH MACRON */
    {   "i-.", 0x1ecb },  /* ị LATIN SMALL LETTER I WITH DOT BELOW */
    {   "i-?", 0x1e2d },  /* ḭ LATIN SMALL LETTER I WITH TILDE BELOW */
    {   "i-o", 0x24d8 },  /* ⓘ CIRCLED LATIN SMALL LETTER I */
    {    "i.", 0x0131 },  /* ı LATIN SMALL LETTER I DOTLESS */
    {    "i2", 0x1ec9 },  /* ỉ LATIN SMALL LETTER I WITH HOOK ABOVE */
    {    "i3", 0x0390 },  /* ΐ GREEK SMALL LETTER IOTA WITH ACUTE AND DIAERESIS */
    {    "i4", 0x3127 },  /* ㄧ BOPOMOFO LETTER I */
    {    "i5", 0x3044 },  /* い HIRAGANA LETTER I */
    {    "i6", 0x30a3 },  /* ィ KATAKANA LETTER SMALL I */
    {    "i:", 0x00ef },  /* ï LATIN SMALL LETTER I WITH DIAERESIS */
    {   "i:'", 0x1e2f },  /* ḯ LATIN SMALL LETTER I WITH DIAERESIS AND ACUTE */
    {    "i;", 0x012f },  /* į LATIN SMALL LETTER I WITH OGONEK */
    {    "i<", 0x01d0 },  /* ǐ LATIN SMALL LETTER I WITH CARON */
    {    "i=", 0x0438 },  /* и CYRILLIC SMALL LETTER I */
    {    "i>", 0x00ee },  /* î LATIN SMALL LETTER I WITH CIRCUMFLEX */
    {    "i?", 0x0129 },  /* ĩ LATIN SMALL LETTER I WITH TILDE */
    {    "ie", 0x0454 },  /* є CYRILLIC SMALL LETTER UKRAINIAN IE */
    {    "ii", 0x0456 },  /* і CYRILLIC SMALL LETTER BYELORUSSIAN-UKRAINIAN I */
    {    "ij", 0x0133 },  /* ĳ LATIN SMALL LIGATURE IJ */
    {    "io", 0x0451 },  /* ё CYRILLIC SMALL LETTER IO */
    {    "iu", 0x3129 },  /* ㄩ BOPOMOFO LETTER IU */
    {    "j%", 0x0458 },  /* ј CYRILLIC SMALL LETTER JE */
    {    "j*", 0x03ca },  /* ϊ GREEK SMALL LETTER IOTA WITH DIAERESIS */
    {    "j+", 0x0649 },  /* ى ARABIC LETTER ALEF MAKSURA */
    {   "j+-", 0xfeef },  /* ﻯ ARABIC LETTER ALEF MAKSURA ISOLATED FORM */
    {   "j+.", 0xfef0 },  /* ﻰ ARABIC LETTER ALEF MAKSURA FINAL FORM */
    {   "j-o", 0x24d9 },  /* ⓙ CIRCLED LATIN SMALL LETTER J */
    {    "j3", 0x03f5 },  /* ϵ GREEK IOTA BELOW */
    {    "j4", 0x3110 },  /* ㄐ BOPOMOFO LETTER J */
    {    "j<", 0x01f0 },  /* ǰ LATIN SMALL LETTER J WITH CARON */
    {    "j=", 0x0439 },  /* й CYRILLIC SMALL LETTER SHORT I */
    {    "j>", 0x0135 },  /* ĵ LATIN SMALL LETTER J WITH CIRCUMFLEX */
    {    "ja", 0x044f },  /* я CYRILLIC SMALL LETTER YA */
    {    "je", 0x044d },  /* э CYRILLIC SMALL LETTER E */
    {    "ju", 0x044e },  /* ю CYRILLIC SMALL LETTER YU */
    {    "k'", 0x1e31 },  /* ḱ LATIN SMALL LETTER K WITH ACUTE */
    {    "k*", 0x03ba },  /* κ GREEK SMALL LETTER KAPPA */
    {    "k+", 0x0643 },  /* ك ARABIC LETTER KAF */
    {   "k+,", 0xfeda },  /* ﻚ ARABIC LETTER KAF INITIAL FORM */
    {   "k+-", 0xfed9 },  /* ﻙ ARABIC LETTER KAF ISOLATED FORM */
    {   "k+.", 0xfedc },  /* ﻜ ARABIC LETTER KAF FINAL FORM */
    {   "k+;", 0xfedb },  /* ﻛ ARABIC LETTER KAF MEDIAL FORM */
    {    "k,", 0x0137 },  /* ķ LATIN SMALL LETTER K WITH CEDILLA */
    {   "k-.", 0x1e33 },  /* ḳ LATIN SMALL LETTER K WITH DOT BELOW */
    {   "k-o", 0x24da },  /* ⓚ CIRCLED LATIN SMALL LETTER K */
    {    "k3", 0x03df },  /* ϟ GREEK SMALL LETTER KOPPA */
    {    "k4", 0x310e },  /* ㄎ BOPOMOFO LETTER K */
    {    "k<", 0x01e9 },  /* ǩ LATIN SMALL LETTER K WITH CARON */
    {    "k=", 0x043a },  /* к CYRILLIC SMALL LETTER KA */
    {    "k_", 0x1e35 },  /* ḵ LATIN SMALL LETTER K WITH LINE BELOW */
    {    "ka", 0x304b },  /* か HIRAGANA LETTER KA */
    {    "ke", 0x3051 },  /* け HIRAGANA LETTER KE */
    {    "ki", 0x304d },  /* き HIRAGANA LETTER KI */
    {    "kj", 0x045c },  /* ќ CYRILLIC SMALL LETTER KJE (Macedonian) */
    {    "kk", 0x0138 },  /* ĸ LATIN SMALL LETTER KRA (Greenlandic) */
    {    "ko", 0x3053 },  /* こ HIRAGANA LETTER KO */
    {    "ku", 0x304f },  /* く HIRAGANA LETTER KU */
    {    "l'", 0x013a },  /* ĺ LATIN SMALL LETTER L WITH ACUTE */
    {    "l*", 0x03bb },  /* λ GREEK SMALL LETTER LAMDA */
    {    "l+", 0x0644 },  /* ل ARABIC LETTER LAM */
    {   "l+,", 0xfede },  /* ﻞ ARABIC LETTER LAM INITIAL FORM */
    {   "l+-", 0xfedd },  /* ﻝ ARABIC LETTER LAM ISOLATED FORM */
    {   "l+.", 0xfee0 },  /* ﻠ ARABIC LETTER LAM FINAL FORM */
    {   "l+;", 0xfedf },  /* ﻟ ARABIC LETTER LAM MEDIAL FORM */
    {    "l,", 0x013c },  /* ļ LATIN SMALL LETTER L WITH CEDILLA */
    {  "l--.", 0x1e39 },  /* ḹ LATIN SMALL LETTER L WITH DOT BELOW AND MACRON */
    {   "l-.", 0x1e37 },  /* ḷ LATIN SMALL LETTER L WITH DOT BELOW */
    {   "l->", 0x1e3d },  /* ḽ LATIN SMALL LETTER L WITH CIRCUMFLEX BELOW */
    {   "l-o", 0x24db },  /* ⓛ CIRCLED LATIN SMALL LETTER L */
    {    "l.", 0x0140 },  /* ŀ LATIN SMALL LETTER L WITH MIDDLE DOT */
    {    "l/", 0x0142 },  /* ł LATIN SMALL LETTER L WITH STROKE */
    {    "l4", 0x310c },  /* ㄌ BOPOMOFO LETTER L */
    {    "l<", 0x013e },  /* ľ LATIN SMALL LETTER L WITH CARON */
    {    "l=", 0x043b },  /* л CYRILLIC SMALL LETTER EL */
    {    "lB", 0x258c },  /* ▌ LEFT HALF BLOCK */
    {   "lH-", 0xfef7 },  /* ﻷ ARABIC LIGATURE LAM WITH ALEF WITH HAMZA ABOVE */
    {   "lH.", 0xfef8 },  /* ﻸ ARABIC LIGATURE LAM WITH ALEF WITH HAMZA ABOVE */
    {   "lM-", 0xfef5 },  /* ﻵ ARABIC LIGATURE LAM WITH ALEF WITH MADDA ABOVE */
    {   "lM.", 0xfef6 },  /* ﻶ ARABIC LIGATURE LAM WITH ALEF WITH MADDA ABOVE */
    {    "l_", 0x1e3b },  /* ḻ LATIN SMALL LETTER L WITH LINE BELOW */
    {   "la-", 0xfefb },  /* ﻻ ARABIC LIGATURE LAM WITH ALEF ISOLATED FORM */
    {   "la.", 0xfefc },  /* ﻼ ARABIC LIGATURE LAM WITH ALEF FINAL FORM */
    {   "lh-", 0xfef9 },  /* ﻹ ARABIC LIGATURE LAM WITH ALEF WITH HAMZA BELOW */
    {   "lh.", 0xfefa },  /* ﻺ ARABIC LIGATURE LAM WITH ALEF WITH HAMZA BELOW */
    {    "lj", 0x0459 },  /* љ CYRILLIC SMALL LETTER LJE */
    {    "m'", 0x1e3f },  /* ḿ LATIN SMALL LETTER M WITH ACUTE */
    {    "m*", 0x03bc },  /* μ GREEK SMALL LETTER MU */
    {    "m+", 0x0645 },  /* م ARABIC LETTER MEEM */
    {   "m+,", 0xfee2 },  /* ﻢ ARABIC LETTER MEEM INITIAL FORM */
    {   "m+-", 0xfee1 },  /* ﻡ ARABIC LETTER MEEM ISOLATED FORM */
    {   "m+.", 0xfee4 },  /* ﻤ ARABIC LETTER MEEM FINAL FORM */
    {   "m+;", 0xfee3 },  /* ﻣ ARABIC LETTER MEEM MEDIAL FORM */
    {   "m-.", 0x1e43 },  /* ṃ LATIN SMALL LETTER M WITH DOT BELOW */
    {   "m-o", 0x24dc },  /* ⓜ CIRCLED LATIN SMALL LETTER M */
    {    "m.", 0x1e41 },  /* ṁ LATIN SMALL LETTER M WITH DOT ABOVE */
    {    "m3", 0x03dd },  /* ϝ GREEK SMALL LETTER DIGAMMA */
    {    "m4", 0x3107 },  /* ㄇ BOPOMOFO LETTER M */
    {    "m=", 0x043c },  /* м CYRILLIC SMALL LETTER EM */
    {    "ma", 0x307e },  /* ま HIRAGANA LETTER MA */
    {    "me", 0x3081 },  /* め HIRAGANA LETTER ME */
    {    "mi", 0x307f },  /* み HIRAGANA LETTER MI */
    {    "mo", 0x3082 },  /* も HIRAGANA LETTER MO */
    {    "mu", 0x3080 },  /* む HIRAGANA LETTER MU */
    {    "n'", 0x0144 },  /* ń LATIN SMALL LETTER N WITH ACUTE */
    {    "n*", 0x03bd },  /* ν GREEK SMALL LETTER NU */
    {    "n+", 0x0646 },  /* ن ARABIC LETTER NOON */
    {   "n+,", 0xfee6 },  /* ﻦ ARABIC LETTER NOON INITIAL FORM */
    {   "n+-", 0xfee5 },  /* ﻥ ARABIC LETTER NOON ISOLATED FORM */
    {   "n+.", 0xfee8 },  /* ﻨ ARABIC LETTER NOON FINAL FORM */
    {   "n+;", 0xfee7 },  /* ﻧ ARABIC LETTER NOON MEDIAL FORM */
    {    "n,", 0x0146 },  /* ņ LATIN SMALL LETTER N WITH CEDILLA */
    {   "n-.", 0x1e47 },  /* ṇ LATIN SMALL LETTER N WITH DOT BELOW */
    {   "n-o", 0x24dd },  /* ⓝ CIRCLED LATIN SMALL LETTER N */
    {    "n.", 0x1e45 },  /* ṅ LATIN SMALL LETTER N WITH DOT ABOVE */
    {    "n4", 0x310b },  /* ㄋ BOPOMOFO LETTER N */
    {    "n5", 0x3093 },  /* ん HIRAGANA LETTER N */
    {    "n<", 0x0148 },  /* ň LATIN SMALL LETTER N WITH CARON */
    {    "n=", 0x043d },  /* н CYRILLIC SMALL LETTER EN */
    {    "n?", 0x00f1 },  /* ñ LATIN SMALL LETTER N WITH TILDE */
    {    "nG", 0x312b },  /* ㄫ BOPOMOFO LETTER NG */
    {    "nS", 0x207f },  /* ⁿ SUPERSCRIPT LATIN SMALL LETTER N */
    {    "n_", 0x1e49 },  /* ṉ LATIN SMALL LETTER N WITH LINE BELOW */
    {    "na", 0x306a },  /* な HIRAGANA LETTER NA */
    {    "ne", 0x306d },  /* ね HIRAGANA LETTER NE */
    {    "ng", 0x014b },  /* ŋ LATIN SMALL LETTER ENG (Lappish) */
    {    "ni", 0x306b },  /* に HIRAGANA LETTER NI */
    {    "nj", 0x045a },  /* њ CYRILLIC SMALL LETTER NJE */
    {    "no", 0x306e },  /* の HIRAGANA LETTER NO */
    {    "nu", 0x306c },  /* ぬ HIRAGANA LETTER NU */
    {    "o!", 0x00f2 },  /* ò LATIN SMALL LETTER O WITH GRAVE */
    {   "o\"", 0x0151 },  /* ő LATIN SMALL LETTER O WITH DOUBLE ACUTE */
    {    "o%", 0x03cc },  /* ό GREEK SMALL LETTER OMICRON WITH ACUTE */
    {    "o'", 0x00f3 },  /* ó LATIN SMALL LETTER O WITH ACUTE */
    {    "o(", 0x014f },  /* ŏ LATIN SMALL LETTER O WITH BREVE */
    {    "o*", 0x03bf },  /* ο GREEK SMALL LETTER OMICRON */
    {    "o-", 0x014d },  /* ō LATIN SMALL LETTER O WITH MACRON */
    {   "o-!", 0x1e51 },  /* ṑ LATIN SMALL LETTER O WITH MACRON AND GRAVE */
    {   "o-'", 0x1e53 },  /* ṓ LATIN SMALL LETTER O WITH MACRON AND ACUTE */
    {   "o-.", 0x1ecd },  /* ọ LATIN SMALL LETTER O WITH DOT BELOW */
    {   "o-o", 0x24de },  /* ⓞ CIRCLED LATIN SMALL LETTER O */
    {    "o/", 0x00f8 },  /* ø LATIN SMALL LETTER O WITH STROKE */
    {   "o/'", 0x01ff },  /* ǿ LATIN SMALL LETTER O WITH STROKE AND ACUTE */
    {    "o1", 0x01ed },  /* ǭ LATIN SMALL LETTER O WITH OGONEK AND MACRON */
    {    "o2", 0x1ecf },  /* ỏ LATIN SMALL LETTER O WITH HOOK ABOVE */
    {    "o3", 0x046b },  /* ѫ CYRILLIC SMALL LETTER BIG YUS */
    {    "o4", 0x311b },  /* ㄛ BOPOMOFO LETTER O */
    {    "o5", 0x304a },  /* お HIRAGANA LETTER O */
    {    "o6", 0x30a9 },  /* ォ KATAKANA LETTER SMALL O */
    {    "o9", 0x01a1 },  /* ơ LATIN SMALL LETTER O WITH HORN */
    {   "o9!", 0x1edd },  /* ờ LATIN SMALL LETTER O WITH HORN AND GRAVE */
    {   "o9'", 0x1edb },  /* ớ LATIN SMALL LETTER O WITH HORN AND ACUTE */
    {  "o9-.", 0x1ee3 },  /* ợ LATIN SMALL LETTER O WITH HORN AND DOT BELOW */
    {   "o92", 0x1edf },  /* ở LATIN SMALL LETTER O WITH HORN AND HOOK ABOVE */
    {   "o9?", 0x1ee1 },  /* ỡ LATIN SMALL LETTER O WITH HORN AND TILDE */
    {    "o:", 0x00f6 },  /* ö LATIN SMALL LETTER O WITH DIAERESIS */
    {    "o;", 0x01eb },  /* ǫ LATIN SMALL LETTER O WITH OGONEK */
    {    "o<", 0x01d2 },  /* ǒ LATIN SMALL LETTER O WITH CARON */
    {    "o=", 0x043e },  /* о CYRILLIC SMALL LETTER O */
    {    "o>", 0x00f4 },  /* ô LATIN SMALL LETTER O WITH CIRCUMFLEX */
    {   "o>!", 0x1ed3 },  /* ồ LATIN SMALL LETTER O WITH CIRCUMFLEX AND GRAVE */
    {   "o>'", 0x1ed1 },  /* ố LATIN SMALL LETTER O WITH CIRCUMFLEX AND ACUTE */
    {  "o>-.", 0x1ed9 },  /* ộ LATIN SMALL LETTER O WITH CIRCUMFLEX AND DOT BELOW */
    {   "o>2", 0x1ed5 },  /* ổ LATIN SMALL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE */
    {   "o>?", 0x1ed7 },  /* ỗ LATIN SMALL LETTER O WITH CIRCUMFLEX AND TILDE */
    {    "o?", 0x00f5 },  /* õ LATIN SMALL LETTER O WITH TILDE */
    {   "o?'", 0x1e4d },  /* ṍ LATIN SMALL LETTER O WITH TILDE AND ACUTE */
    {   "o?:", 0x1e4f },  /* ṏ LATIN SMALL LETTER O WITH TILDE AND DIAERESIS */
    {    "oC", 0x2103 },  /* ℃ DEGREE CENTIGRADE */
    {    "oF", 0x2109 },  /* ℉ DEGREE FAHRENHEIT */
    {    "oe", 0x0153 },  /* œ LATIN SMALL LIGATURE OE */
    {    "oi", 0x01a3 },  /* ƣ LATIN SMALL LETTER OI */
    {    "ou", 0x3121 },  /* ㄡ BOPOMOFO LETTER OU */
    {    "p'", 0x1e55 },  /* ṕ LATIN SMALL LETTER P WITH ACUTE */
    {    "p*", 0x03c0 },  /* π GREEK SMALL LETTER PI */
    {    "p+", 0x067e },  /* پ ARABIC LETTER PEH */
    {   "p-o", 0x24df },  /* ⓟ CIRCLED LATIN SMALL LETTER P */
    {    "p.", 0x1e57 },  /* ṗ LATIN SMALL LETTER P WITH DOT ABOVE */
    {    "p3", 0x03e1 },  /* ϡ GREEK SMALL LETTER SAMPI */
    {    "p4", 0x3106 },  /* ㄆ BOPOMOFO LETTER P */
    {    "p=", 0x043f },  /* п CYRILLIC SMALL LETTER PE */
    {    "pa", 0x3071 },  /* ぱ HIRAGANA LETTER PA */
    {    "pe", 0x307a },  /* ぺ HIRAGANA LETTER PE */
    {    "pi", 0x3074 },  /* ぴ HIRAGANA LETTER PI */
    {    "pm", 0xe020 },  /*  POST MERIDIAM SIGN (ISO-IR-149 0268) */
    {    "po", 0x307d },  /* ぽ HIRAGANA LETTER PO */
    {    "pu", 0x3077 },  /* ぷ HIRAGANA LETTER PU */
    {    "q*", 0x03c8 },  /* ψ GREEK SMALL LETTER PSI */
    {    "q+", 0x0642 },  /* ق ARABIC LETTER QAF */
    {   "q+,", 0xfed6 },  /* ﻖ ARABIC LETTER QAF INITIAL FORM */
    {   "q+-", 0xfed5 },  /* ﻕ ARABIC LETTER QAF ISOLATED FORM */
    {   "q+.", 0xfed8 },  /* ﻘ ARABIC LETTER QAF FINAL FORM */
    {   "q+;", 0xfed7 },  /* ﻗ ARABIC LETTER QAF MEDIAL FORM */
    {   "q-o", 0x24e0 },  /* ⓠ CIRCLED LATIN SMALL LETTER Q */
    {    "q4", 0x3111 },  /* ㄑ BOPOMOFO LETTER Q */
    {    "r'", 0x0155 },  /* ŕ LATIN SMALL LETTER R WITH ACUTE */
    {    "r*", 0x03c1 },  /* ρ GREEK SMALL LETTER RHO */
    {    "r+", 0x0631 },  /* ر ARABIC LETTER REH */
    {   "r+-", 0xfead },  /* ﺭ ARABIC LETTER REH ISOLATED FORM */
    {   "r+.", 0xfeae },  /* ﺮ ARABIC LETTER REH FINAL FORM */
    {    "r,", 0x0157 },  /* ŗ LATIN SMALL LETTER R WITH CEDILLA */
    {  "r--.", 0x1e5d },  /* ṝ LATIN SMALL LETTER R WITH DOT BELOW AND MACRON */
    {   "r-.", 0x1e5b },  /* ṛ LATIN SMALL LETTER R WITH DOT BELOW */
    {   "r-o", 0x24e1 },  /* ⓡ CIRCLED LATIN SMALL LETTER R */
    {    "r.", 0x1e59 },  /* ṙ LATIN SMALL LETTER R WITH DOT ABOVE */
    {    "r4", 0x3116 },  /* ㄖ BOPOMOFO LETTER R */
    {    "r<", 0x0159 },  /* ř LATIN SMALL LETTER R WITH CARON */
    {    "r=", 0x0440 },  /* р CYRILLIC SMALL LETTER ER */
    {    "r_", 0x1e5f },  /* ṟ LATIN SMALL LETTER R WITH LINE BELOW */
    {    "ra", 0x3089 },  /* ら HIRAGANA LETTER RA */
    {    "re", 0x308c },  /* れ HIRAGANA LETTER RE */
    {    "ri", 0x308a },  /* り HIRAGANA LETTER RI */
    {    "ro", 0x308d },  /* ろ HIRAGANA LETTER RO */
    {    "ru", 0x308b },  /* る HIRAGANA LETTER RU */
    {    "s%", 0x0448 },  /* ш CYRILLIC SMALL LETTER SHA */
    {    "s'", 0x015b },  /* ś LATIN SMALL LETTER S WITH ACUTE */
    {   "s'.", 0x1e65 },  /* ṥ LATIN SMALL LETTER S WITH ACUTE AND DOT ABOVE */
    {    "s*", 0x03c3 },  /* σ GREEK SMALL LETTER SIGMA */
    {    "s+", 0x0633 },  /* س ARABIC LETTER SEEN */
    {   "s+,", 0xfeb2 },  /* ﺲ ARABIC LETTER SEEN INITIAL FORM */
    {   "s+-", 0xfeb1 },  /* ﺱ ARABIC LETTER SEEN ISOLATED FORM */
    {   "s+.", 0xfeb4 },  /* ﺴ ARABIC LETTER SEEN FINAL FORM */
    {   "s+;", 0xfeb3 },  /* ﺳ ARABIC LETTER SEEN MEDIAL FORM */
    {    "s,", 0x015f },  /* ş LATIN SMALL LETTER S WITH CEDILLA */
    {   "s-.", 0x1e63 },  /* ṣ LATIN SMALL LETTER S WITH DOT BELOW */
    {   "s-o", 0x24e2 },  /* ⓢ CIRCLED LATIN SMALL LETTER S */
    {    "s.", 0x1e61 },  /* ṡ LATIN SMALL LETTER S WITH DOT ABOVE */
    {    "s4", 0x3119 },  /* ㄙ BOPOMOFO LETTER S */
    {    "s<", 0x0161 },  /* š LATIN SMALL LETTER S WITH CARON */
    {   "s<.", 0x1e67 },  /* ṧ LATIN SMALL LETTER S WITH CARON AND DOT ABOVE */
    {    "s=", 0x0441 },  /* с CYRILLIC SMALL LETTER ES */
    {    "s>", 0x015d },  /* ŝ LATIN SMALL LETTER S WITH CIRCUMFLEX */
    {    "sB", 0x25aa },  /* ▪ BLACK SMALL SQUARE */
    {    "sa", 0x3055 },  /* さ HIRAGANA LETTER SA */
    {    "sc", 0x0449 },  /* щ CYRILLIC SMALL LETTER SHCHA */
    {    "se", 0x305b },  /* せ HIRAGANA LETTER SE */
    {    "sh", 0x3115 },  /* ㄕ BOPOMOFO LETTER SH */
    {    "si", 0x3057 },  /* し HIRAGANA LETTER SI */
    {    "sn", 0x0634 },  /* ش ARABIC LETTER SHEEN */
    {   "sn,", 0xfeb6 },  /* ﺶ ARABIC LETTER SHEEN INITIAL FORM */
    {   "sn-", 0xfeb5 },  /* ﺵ ARABIC LETTER SHEEN ISOLATED FORM */
    {   "sn.", 0xfeb8 },  /* ﺸ ARABIC LETTER SHEEN FINAL FORM */
    {   "sn;", 0xfeb7 },  /* ﺷ ARABIC LETTER SHEEN MEDIAL FORM */
    {    "so", 0x305d },  /* そ HIRAGANA LETTER SO */
    {    "ss", 0x00df },  /* ß LATIN SMALL LETTER SHARP S (German) */
    {    "st", 0xfb06 },  /* ﬆ LATIN SMALL LIGATURE ST */
    {    "su", 0x3059 },  /* す HIRAGANA LETTER SU */
    {    "t*", 0x03c4 },  /* τ GREEK SMALL LETTER TAU */
    {    "t+", 0x062a },  /* ت ARABIC LETTER TEH */
    {   "t+,", 0xfe96 },  /* ﺖ ARABIC LETTER TEH INITIAL FORM */
    {   "t+-", 0xfe95 },  /* ﺕ ARABIC LETTER TEH ISOLATED FORM */
    {   "t+.", 0xfe98 },  /* ﺘ ARABIC LETTER TEH FINAL FORM */
    {   "t+;", 0xfe97 },  /* ﺗ ARABIC LETTER TEH MEDIAL FORM */
    {    "t,", 0x0163 },  /* ţ LATIN SMALL LETTER T WITH CEDILLA */
    {   "t-.", 0x1e6d },  /* ṭ LATIN SMALL LETTER T WITH DOT BELOW */
    {   "t->", 0x1e71 },  /* ṱ LATIN SMALL LETTER T WITH CIRCUMFLEX BELOW */
    {   "t-o", 0x24e3 },  /* ⓣ CIRCLED LATIN SMALL LETTER T */
    {    "t.", 0x1e6b },  /* ṫ LATIN SMALL LETTER T WITH DOT ABOVE */
    {    "t/", 0x0167 },  /* ŧ LATIN SMALL LETTER T WITH STROKE */
    {    "t3", 0x03db },  /* ϛ GREEK SMALL LETTER STIGMA */
    {    "t4", 0x310a },  /* ㄊ BOPOMOFO LETTER T */
    {    "t:", 0x1e97 },  /* ẗ LATIN SMALL LETTER T WITH DIAERESIS */
    {    "t<", 0x0165 },  /* ť LATIN SMALL LETTER T WITH CARON */
    {    "t=", 0x0442 },  /* т CYRILLIC SMALL LETTER TE */
    {    "tU", 0x3063 },  /* っ HIRAGANA LETTER SMALL TU */
    {    "t_", 0x1e6f },  /* ṯ LATIN SMALL LETTER T WITH LINE BELOW */
    {    "ta", 0x305f },  /* た HIRAGANA LETTER TA */
    {    "te", 0x3066 },  /* て HIRAGANA LETTER TE */
    {   "tel", 0x260f },  /* ☏ WHITE TELEPHONE */
    {    "th", 0x00fe },  /* þ LATIN SMALL LETTER THORN (Icelandic) */
    {    "ti", 0x3061 },  /* ち HIRAGANA LETTER TI */
    {    "tj", 0x0637 },  /* ط ARABIC LETTER TAH */
    {   "tj,", 0xfec2 },  /* ﻂ ARABIC LETTER TAH INITIAL FORM */
    {   "tj-", 0xfec1 },  /* ﻁ ARABIC LETTER TAH ISOLATED FORM */
    {   "tj.", 0xfec4 },  /* ﻄ ARABIC LETTER TAH FINAL FORM */
    {   "tj;", 0xfec3 },  /* ﻃ ARABIC LETTER TAH MEDIAL FORM */
    {    "tk", 0x062b },  /* ث ARABIC LETTER THEH */
    {   "tk,", 0xfe9a },  /* ﺚ ARABIC LETTER THEH INITIAL FORM */
    {   "tk-", 0xfe99 },  /* ﺙ ARABIC LETTER THEH ISOLATED FORM */
    {   "tk.", 0xfe9c },  /* ﺜ ARABIC LETTER THEH FINAL FORM */
    {   "tk;", 0xfe9b },  /* ﺛ ARABIC LETTER THEH MEDIAL FORM */
    {    "tm", 0x0629 },  /* ة ARABIC LETTER TEH MARBUTA */
    {   "tm-", 0xfe93 },  /* ﺓ ARABIC LETTER TEH MARBUTA ISOLATED FORM */
    {   "tm.", 0xfe94 },  /* ﺔ ARABIC LETTER TEH MARBUTA FINAL FORM */
    {    "to", 0x3068 },  /* と HIRAGANA LETTER TO */
    {    "ts", 0x045b },  /* ћ CYRILLIC SMALL LETTER TSHE (Serbocroatian) */
    {    "tu", 0x3064 },  /* つ HIRAGANA LETTER TU */
    {    "u!", 0x00f9 },  /* ù LATIN SMALL LETTER U WITH GRAVE */
    {   "u\"", 0x0171 },  /* ű LATIN SMALL LETTER U WITH DOUBLE ACUTE */
    {    "u%", 0x03cd },  /* ύ GREEK SMALL LETTER UPSILON WITH ACUTE */
    {    "u'", 0x00fa },  /* ú LATIN SMALL LETTER U WITH ACUTE */
    {    "u(", 0x016d },  /* ŭ LATIN SMALL LETTER U WITH BREVE */
    {    "u*", 0x03c5 },  /* υ GREEK SMALL LETTER UPSILON */
    {    "u-", 0x016b },  /* ū LATIN SMALL LETTER U WITH MACRON */
    {  "u--:", 0x1e73 },  /* ṳ LATIN SMALL LETTER U WITH DIAERESIS BELOW */
    {   "u-.", 0x1ee5 },  /* ụ LATIN SMALL LETTER U WITH DOT BELOW */
    {   "u-:", 0x1e7b },  /* ṻ LATIN SMALL LETTER U WITH MACRON AND DIAERESIS */
    {   "u->", 0x1e77 },  /* ṷ LATIN SMALL LETTER U WITH CIRCUMFLEX BELOW */
    {   "u-?", 0x1e75 },  /* ṵ LATIN SMALL LETTER U WITH TILDE BELOW */
    {   "u-o", 0x24e4 },  /* ⓤ CIRCLED LATIN SMALL LETTER U */
    {    "u0", 0x016f },  /* ů LATIN SMALL LETTER U WITH RING ABOVE */
    {    "u2", 0x1ee7 },  /* ủ LATIN SMALL LETTER U WITH HOOK ABOVE */
    {    "u3", 0x03b0 },  /* ΰ GREEK SMALL LETTER UPSILON WITH ACUTE AND DIAERESIS */
    {    "u4", 0x3128 },  /* ㄨ BOPOMOFO LETTER U */
    {    "u5", 0x3046 },  /* う HIRAGANA LETTER U */
    {    "u6", 0x30a5 },  /* ゥ KATAKANA LETTER SMALL U */
    {    "u9", 0x01b0 },  /* ư LATIN SMALL LETTER U WITH HORN */
    {   "u9!", 0x1eeb },  /* ừ LATIN SMALL LETTER U WITH HORN AND GRAVE */
    {   "u9'", 0x1ee9 },  /* ứ LATIN SMALL LETTER U WITH HORN AND ACUTE */
    {  "u9-.", 0x1ef1 },  /* ự LATIN SMALL LETTER U WITH HORN AND DOT BELOW */
    {   "u92", 0x1eed },  /* ử LATIN SMALL LETTER U WITH HORN AND HOOK ABOVE */
    {   "u9?", 0x1eef },  /* ữ LATIN SMALL LETTER U WITH HORN AND TILDE */
    {    "u:", 0x00fc },  /* ü LATIN SMALL LETTER U WITH DIAERESIS */
    {   "u:!", 0x01dc },  /* ǜ LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE */
    {   "u:'", 0x01d8 },  /* ǘ LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE */
    {   "u:-", 0x01d6 },  /* ǖ LATIN SMALL LETTER U WITH DIAERESIS AND MACRON */
    {   "u:<", 0x01da },  /* ǚ LATIN SMALL LETTER U WITH DIAERESIS AND CARON */
    {    "u;", 0x0173 },  /* ų LATIN SMALL LETTER U WITH OGONEK */
    {    "u<", 0x01d4 },  /* ǔ LATIN SMALL LETTER U WITH CARON */
    {    "u=", 0x0443 },  /* у CYRILLIC SMALL LETTER U */
    {    "u>", 0x00fb },  /* û LATIN SMALL LETTER U WITH CIRCUMFLEX */
    {    "u?", 0x0169 },  /* ũ LATIN SMALL LETTER U WITH TILDE */
    {   "u?'", 0x1e79 },  /* ṹ LATIN SMALL LETTER U WITH TILDE AND ACUTE */
    {   "uDH", 0x2548 },  /* ╈ BOX DRAWINGS UP LIGHT AND DOWN HORIZONTAL HEAVY */
    {   "uDL", 0x252a },  /* ┪ BOX DRAWINGS UP LIGHT AND LEFT DOWN HEAVY */
    {  "uDLr", 0x2545 },  /* ╅ BOX DRAWINGS LEFT DOWN HEAVY AND RIGHT UP LIGHT */
    {   "uDR", 0x2522 },  /* ┢ BOX DRAWINGS UP LIGHT AND RIGHT DOWN HEAVY */
    {   "uDh", 0x2541 },  /* ╁ BOX DRAWINGS DOWN HEAVY AND UP HORIZONTAL LIGHT */
    {   "uDl", 0x2527 },  /* ┧ BOX DRAWINGS DOWN HEAVY AND LEFT UP LIGHT */
    {  "uDlR", 0x2546 },  /* ╆ BOX DRAWINGS RIGHT DOWN HEAVY AND LEFT UP LIGHT */
    {   "uDr", 0x251f },  /* ┟ BOX DRAWINGS DOWN HEAVY AND RIGHT UP LIGHT */
    {    "uH", 0x2537 },  /* ┷ BOX DRAWINGS UP LIGHT AND HORIZONTAL HEAVY */
    {    "uL", 0x2519 },  /* ┙ BOX DRAWINGS UP LIGHT AND LEFT HEAVY */
    {   "uLr", 0x2535 },  /* ┵ BOX DRAWINGS LEFT HEAVY AND RIGHT UP LIGHT */
    {    "uR", 0x2515 },  /* ┕ BOX DRAWINGS UP LIGHT AND RIGHT HEAVY */
    {    "uT", 0x25b3 },  /* △ WHITE UP-POINTING TRIANGLE */
    {    "uh", 0x2534 },  /* ┴ BOX DRAWINGS LIGHT UP AND HORIZONTAL */
    {    "ul", 0x2518 },  /* ┘ BOX DRAWINGS LIGHT UP AND LEFT */
    {   "ulR", 0x2536 },  /* ┶ BOX DRAWINGS RIGHT HEAVY AND LEFT UP LIGHT */
    {    "ur", 0x2514 },  /* └ BOX DRAWINGS LIGHT UP AND RIGHT */
    {    "v%", 0x045e },  /* ў CYRILLIC SMALL LETTER SHORT U (Byelorussian) */
    {    "v*", 0x03cb },  /* ϋ GREEK SMALL LETTER UPSILON WITH DIAERESIS */
    {    "v+", 0x06a4 },  /* ڤ ARABIC LETTER VEH */
    {   "v-.", 0x1e7f },  /* ṿ LATIN SMALL LETTER V WITH DOT BELOW */
    {   "v-o", 0x24e5 },  /* ⓥ CIRCLED LATIN SMALL LETTER V */
    {    "v3", 0x0475 },  /* ѵ CYRILLIC SMALL LETTER IZHITSA */
    {    "v4", 0x312a },  /* ㄪ BOPOMOFO LETTER V */
    {    "v=", 0x0432 },  /* в CYRILLIC SMALL LETTER VE */
    {    "v?", 0x1e7d },  /* ṽ LATIN SMALL LETTER V WITH TILDE */
    {    "vH", 0x253f },  /* ┿ BOX DRAWINGS VERTICAL LIGHT AND HORIZONTAL HEAVY */
    {    "vL", 0x2525 },  /* ┥ BOX DRAWINGS VERTICAL LIGHT AND LEFT HEAVY */
    {   "vLr", 0x253d },  /* ┽ BOX DRAWINGS LEFT HEAVY AND RIGHT VERTICAL LIGHT */
    {    "vR", 0x251d },  /* ┝ BOX DRAWINGS VERTICAL LIGHT AND RIGHT HEAVY */
    {    "vh", 0x253c },  /* ┼ BOX DRAWINGS LIGHT VERTICAL AND HORIZONTAL */
    {    "vl", 0x2524 },  /* ┤ BOX DRAWINGS LIGHT VERTICAL AND LEFT */
    {   "vlR", 0x253e },  /* ┾ BOX DRAWINGS RIGHT HEAVY AND LEFT VERTICAL LIGHT */
    {    "vr", 0x251c },  /* ├ BOX DRAWINGS LIGHT VERTICAL AND RIGHT */
    {    "vu", 0x3094 },  /* ゔ HIRAGANA LETTER VU */
    {    "vv", 0x2502 },  /* │ BOX DRAWINGS LIGHT VERTICAL */
    {    "w!", 0x1e81 },  /* ẁ LATIN SMALL LETTER W WITH GRAVE */
    {    "w%", 0x03ce },  /* ώ GREEK SMALL LETTER OMEGA WITH ACUTE */
    {    "w'", 0x1e83 },  /* ẃ LATIN SMALL LETTER W WITH ACUTE */
    {    "w*", 0x03c9 },  /* ω GREEK SMALL LETTER OMEGA */
    {    "w+", 0x0648 },  /* و ARABIC LETTER WAW */
    {   "w+-", 0xfeed },  /* ﻭ ARABIC LETTER WAW ISOLATED FORM */
    {   "w+.", 0xfeee },  /* ﻮ ARABIC LETTER WAW FINAL FORM */
    {   "w-.", 0x1e89 },  /* ẉ LATIN SMALL LETTER W WITH DOT BELOW */
    {   "w-o", 0x24e6 },  /* ⓦ CIRCLED LATIN SMALL LETTER W */
    {    "w.", 0x1e87 },  /* ẇ LATIN SMALL LETTER W WITH DOT ABOVE */
    {    "w0", 0x1e98 },  /* ẘ LATIN SMALL LETTER W WITH RING ABOVE */
    {    "w:", 0x1e85 },  /* ẅ LATIN SMALL LETTER W WITH DIAERESIS */
    {    "w>", 0x0175 },  /* ŵ LATIN SMALL LETTER W WITH CIRCUMFLEX */
    {    "wA", 0x308e },  /* ゎ HIRAGANA LETTER SMALL WA */
    {    "wH", 0x0624 },  /* ؤ ARABIC LETTER WAW WITH HAMZA ABOVE */
    {    "wa", 0x308f },  /* わ HIRAGANA LETTER WA */
    {    "we", 0x3091 },  /* ゑ HIRAGANA LETTER WE */
    {    "wi", 0x3090 },  /* ゐ HIRAGANA LETTER WI */
    {    "wo", 0x3092 },  /* を HIRAGANA LETTER WO */
    {    "x*", 0x03c7 },  /* χ GREEK SMALL LETTER CHI */
    {    "x+", 0x062e },  /* خ ARABIC LETTER KHAH */
    {   "x+,", 0xfea6 },  /* ﺦ ARABIC LETTER KHAH INITIAL FORM */
    {   "x+-", 0xfea5 },  /* ﺥ ARABIC LETTER KHAH ISOLATED FORM */
    {   "x+.", 0xfea8 },  /* ﺨ ARABIC LETTER KHAH FINAL FORM */
    {   "x+;", 0xfea7 },  /* ﺧ ARABIC LETTER KHAH MEDIAL FORM */
    {   "x-o", 0x24e7 },  /* ⓧ CIRCLED LATIN SMALL LETTER X */
    {    "x.", 0x1e8b },  /* ẋ LATIN SMALL LETTER X WITH DOT ABOVE */
    {    "x4", 0x3112 },  /* ㄒ BOPOMOFO LETTER X */
    {    "x:", 0x1e8d },  /* ẍ LATIN SMALL LETTER X WITH DIAERESIS */
    {    "y!", 0x1ef3 },  /* ỳ LATIN SMALL LETTER Y WITH GRAVE */
    {    "y%", 0x03ae },  /* ή GREEK SMALL LETTER ETA WITH ACUTE */
    {    "y'", 0x00fd },  /* ý LATIN SMALL LETTER Y WITH ACUTE */
    {    "y*", 0x03b7 },  /* η GREEK SMALL LETTER ETA */
    {    "y+", 0x064a },  /* ي ARABIC LETTER YEH */
    {   "y+,", 0xfef2 },  /* ﻲ ARABIC LETTER YEH INITIAL FORM */
    {   "y+-", 0xfef1 },  /* ﻱ ARABIC LETTER YEH ISOLATED FORM */
    {   "y+.", 0xfef4 },  /* ﻴ ARABIC LETTER YEH FINAL FORM */
    {   "y+;", 0xfef3 },  /* ﻳ ARABIC LETTER YEH MEDIAL FORM */
    {   "y-.", 0x1ef5 },  /* ỵ LATIN SMALL LETTER Y WITH DOT BELOW */
    {   "y-o", 0x24e8 },  /* ⓨ CIRCLED LATIN SMALL LETTER Y */
    {    "y.", 0x1e8f },  /* ẏ LATIN SMALL LETTER Y WITH DOT ABOVE */
    {    "y0", 0x1e99 },  /* ẙ LATIN SMALL LETTER Y WITH RING ABOVE */
    {    "y2", 0x1ef7 },  /* ỷ LATIN SMALL LETTER Y WITH HOOK ABOVE */
    {    "y3", 0x0463 },  /* ѣ CYRILLIC SMALL LETTER YAT */
    {    "y:", 0x00ff },  /* ÿ LATIN SMALL LETTER Y WITH DIAERESIS */
    {    "y=", 0x044b },  /* ы CYRILLIC SMALL LETTER YERU */
    {    "y>", 0x0177 },  /* ŷ LATIN SMALL LETTER Y WITH CIRCUMFLEX */
    {    "y?", 0x1ef9 },  /* ỹ LATIN SMALL LETTER Y WITH TILDE */
    {    "yA", 0x3083 },  /* ゃ HIRAGANA LETTER SMALL YA */
    {    "yH", 0x0626 },  /* ئ ARABIC LETTER YEH WITH HAMZA ABOVE */
    {    "yO", 0x3087 },  /* ょ HIRAGANA LETTER SMALL YO */
    {    "yU", 0x3085 },  /* ゅ HIRAGANA LETTER SMALL YU */
    {    "ya", 0x3084 },  /* や HIRAGANA LETTER YA */
    {    "yi", 0x0457 },  /* ї CYRILLIC SMALL LETTER YI (Ukrainian) */
    {    "yo", 0x3088 },  /* よ HIRAGANA LETTER YO */
    {    "yr", 0x01a6 },  /* Ʀ LATIN LETTER YR */
    {    "yu", 0x3086 },  /* ゆ HIRAGANA LETTER YU */
    {    "z%", 0x0436 },  /* ж CYRILLIC SMALL LETTER ZHE */
    {    "z'", 0x017a },  /* ź LATIN SMALL LETTER Z WITH ACUTE */
    {    "z*", 0x03b6 },  /* ζ GREEK SMALL LETTER ZETA */
    {    "z+", 0x0632 },  /* ز ARABIC LETTER ZAIN */
    {   "z+-", 0xfeaf },  /* ﺯ ARABIC LETTER ZAIN ISOLATED FORM */
    {   "z+.", 0xfeb0 },  /* ﺰ ARABIC LETTER ZAIN FINAL FORM */
    {   "z-.", 0x1e93 },  /* ẓ LATIN SMALL LETTER Z WITH DOT BELOW */
    {   "z-o", 0x24e9 },  /* ⓩ CIRCLED LATIN SMALL LETTER Z */
    {    "z.", 0x017c },  /* ż LATIN SMALL LETTER Z WITH DOT ABOVE */
    {    "z/", 0x01b6 },  /* ƶ LATIN SMALL LETTER Z WITH STROKE */
    {    "z4", 0x3117 },  /* ㄗ BOPOMOFO LETTER Z */
    {    "z<", 0x017e },  /* ž LATIN SMALL LETTER Z WITH CARON */
    {    "z=", 0x0437 },  /* з CYRILLIC SMALL LETTER ZE */
    {    "z>", 0x1e91 },  /* ẑ LATIN SMALL LETTER Z WITH CIRCUMFLEX */
    {    "zH", 0x0638 },  /* ظ ARABIC LETTER ZAH */
    {   "zH,", 0xfec6 },  /* ﻆ ARABIC LETTER ZAH INITIAL FORM */
    {   "zH-", 0xfec5 },  /* ﻅ ARABIC LETTER ZAH ISOLATED FORM */
    {   "zH.", 0xfec8 },  /* ﻈ ARABIC LETTER ZAH FINAL FORM */
    {   "zH;", 0xfec7 },  /* ﻇ ARABIC LETTER ZAH MEDIAL FORM */
    {    "z_", 0x1e95 },  /* ẕ LATIN SMALL LETTER Z WITH LINE BELOW */
    {    "za", 0x3056 },  /* ざ HIRAGANA LETTER ZA */
    {    "ze", 0x305c },  /* ぜ HIRAGANA LETTER ZE */
    {    "zh", 0x3113 },  /* ㄓ BOPOMOFO LETTER ZH */
    {    "zi", 0x3058 },  /* じ HIRAGANA LETTER ZI */
    {    "zo", 0x305e },  /* ぞ HIRAGANA LETTER ZO */
    {    "zu", 0x305a }   /* ず HIRAGANA LETTER ZU */
};

const int NUM_MGRAPHS = sizeof(mgraphs)/sizeof(mgraphs[0]);
