#include <stdlib.h>
#include <stdio.h>
#include <assert.h>
#include <sys/types.h>
#include <unistd.h>

#include "_stdint.h"
#include "xatoms.h"
#include "x11.h"
#include "defaults.h"

Display *disp;
XFontStruct *xfs;

struct win win;
/* arch-tag: 39b298f4-034c-4671-a62b-63ea8d76d3a9 */

static void 
x11_newwindow(int argc, char *argv[]) 
{
	XClassHint *xch;
	XWMHints *hints;
        uint32_t pid;

        win.w = XCreateSimpleWindow(disp,ROOT,0,0,640,480,1, DC_borderColor ,  DC_background);
	XSelectInput(disp,win.w,StructureNotifyMask|VisibilityChangeMask);

        xch = XAllocClassHint();
	xch->res_name = "uterm";
	xch->res_class = "Uterm";

	hints = XAllocWMHints();
	hints->window_group = win.w;
	hints->flags = WindowGroupHint;

	XmbSetWMProperties(disp, win.w, "Terminal", "Terminal", argv, argc, NULL, hints, xch);
	XFree(xch);
	XFree(hints);

	pid = getpid();
	XChangeProperty(disp, win.w, XA__NET_WM_PID, XA_CARDINAL, 32, PropModeReplace, (unsigned char *)&pid, 1);

	XSetWMProtocols(disp,win.w,&XA_WM_DELETE_WINDOW,1);
        //win.pm = XCreatePixmap(disp, win.w, 640, 480, DefaultDepth(disp, DefaultScreen(disp)));
        win.width = 640;
        win.height = 480;
        //XSetWindowBackgroundPixmap(disp, win.w, None);
        win.gc = XCreateGC(disp, win.w, 0, NULL );
        XSetGraphicsExposures(disp, win.gc, 0);

}

void
x11_init(int argc, char *argv[])
{
	if((disp=XOpenDisplay(NULL)) == NULL) {
		fprintf(stderr,"X11 says \"I can't open display: %s\"\n", XDisplayName(NULL));
		exit(2);
	}
        intern_xatoms(disp);
        setup_defaults(disp, "uterm");
        setup_default_colors(disp, CMAP);
	x11_newwindow(argc, argv);
	xfs = XLoadQueryFont(disp,D_font);
        XSetFont(disp, win.gc, xfs->fid);
        assert(xfs);
}

void
x11_close(void) 
{
	XCloseDisplay(disp);
}

void
get_charcell_size(int *width, int *height) {
        if (xfs->per_char)
                *width = xfs->per_char['m'].width;
        else
                *width = xfs->min_bounds.width;
        *height = xfs->ascent + xfs->descent;
}

